@@ -29,9 +29,9 @@ import (
 
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
-	"sigs.k8s.io/controller-runtime/pkg/client/fake"
 
-	snapshotv1 "github.com/kubernetes-csi/external-snapshotter/client/v6/apis/volumesnapshot/v1"
+	snapclientfake "github.com/kubernetes-csi/external-snapshotter/client/v6/clientset/versioned/fake"
+
 	admissionv1 "k8s.io/api/admission/v1"
 	corev1 "k8s.io/api/core/v1"
 	k8sv1 "k8s.io/api/core/v1"
@@ -41,10 +41,10 @@ import (
 	fakeclient "k8s.io/client-go/kubernetes/fake"
 	"k8s.io/utils/ptr"
 
-	snapclientfake "github.com/kubernetes-csi/external-snapshotter/client/v6/clientset/versioned/fake"
-	cdiclientfake "kubevirt.io/containerized-data-importer/pkg/client/clientset/versioned/fake"
+	"sigs.k8s.io/controller-runtime/pkg/client/fake"
 
 	cdiv1 "kubevirt.io/containerized-data-importer-api/pkg/apis/core/v1beta1"
+	cdiclientfake "kubevirt.io/containerized-data-importer/pkg/client/clientset/versioned/fake"
 )
 
 var (
@@ -323,7 +323,7 @@ var _ = Describe("Validating Webhook", func() {
 				HTTP: &cdiv1.DataVolumeSourceHTTP{URL: "http://www.example.com"},
 			}
 			storage := &cdiv1.StorageSpec{
-				Resources: corev1.ResourceRequirements{
+				Resources: corev1.VolumeResourceRequirements{
 					Requests: corev1.ResourceList{
 						corev1.ResourceStorage: resource.MustParse("500Mi"),
 					},
@@ -374,11 +374,19 @@ var _ = Describe("Validating Webhook", func() {
 			Expect(resp.Allowed).To(BeFalse())
 		})
 
+		It("should reject DataVolume with size smaller than 1MiB", func() {
+			dataVolume := newBlankDataVolume("blank")
+			quantity, err := resource.ParseQuantity("9")
+			Expect(err).ToNot(HaveOccurred())
+			dataVolume.Spec.PVC.Resources.Requests["storage"] = quantity
+			resp := validateDataVolumeCreate(dataVolume)
+			Expect(resp.Allowed).To(BeFalse())
+		})
+
 		It("should accept DataVolume with Blank source and no content type", func() {
 			dataVolume := newBlankDataVolume("blank")
 			resp := validateDataVolumeCreate(dataVolume)
 			Expect(resp.Allowed).To(BeTrue())
-
 		})
 
 		It("should accept DataVolume with Blank source and kubevirt contentType", func() {
@@ -546,10 +554,10 @@ var _ = Describe("Validating Webhook", func() {
 			Entry("should reject clones with both Storage and PVC spec", &cdiv1.StorageSpec{}, &corev1.PersistentVolumeClaimSpec{}, false),
 			Entry("should accept empty Storage spec when cloning PVC", &cdiv1.StorageSpec{}, nil, true),
 			Entry("should accept blank Resources when cloning using Storage API", &cdiv1.StorageSpec{
-				Resources: corev1.ResourceRequirements{},
+				Resources: corev1.VolumeResourceRequirements{},
 			}, nil, true),
 			Entry("should accept empty Requests when cloning using Storage API", &cdiv1.StorageSpec{
-				Resources: corev1.ResourceRequirements{
+				Resources: corev1.VolumeResourceRequirements{
 					Requests: make(map[corev1.ResourceName]resource.Quantity),
 				},
 			}, nil, true),
@@ -557,7 +565,7 @@ var _ = Describe("Validating Webhook", func() {
 				AccessModes: []corev1.PersistentVolumeAccessMode{
 					corev1.ReadWriteOnce,
 				},
-				Resources: corev1.ResourceRequirements{
+				Resources: corev1.VolumeResourceRequirements{
 					Requests: make(map[corev1.ResourceName]resource.Quantity),
 				},
 			}, false),
@@ -569,7 +577,7 @@ var _ = Describe("Validating Webhook", func() {
 			}
 			requests := make(map[corev1.ResourceName]resource.Quantity)
 			storage := &cdiv1.StorageSpec{
-				Resources: corev1.ResourceRequirements{
+				Resources: corev1.VolumeResourceRequirements{
 					Requests: requests,
 				},
 			}
@@ -611,55 +619,6 @@ var _ = Describe("Validating Webhook", func() {
 			Expect(resp.Allowed).To(BeTrue())
 		})
 
-		It("should reject snapshot clone when input size is lower than recommended restore size", func() {
-			size := resource.MustParse("1G")
-			snapshot := &snapshotv1.VolumeSnapshot{
-				ObjectMeta: metav1.ObjectMeta{
-					Name:      "testsnap",
-					Namespace: testNamespace,
-				},
-				Status: &snapshotv1.VolumeSnapshotStatus{
-					RestoreSize: &size,
-				},
-			}
-			storage := &cdiv1.StorageSpec{
-				Resources: corev1.ResourceRequirements{
-					Requests: corev1.ResourceList{
-						corev1.ResourceStorage: resource.MustParse("500Mi"),
-					},
-				},
-			}
-			snapSource := &cdiv1.DataVolumeSource{
-				Snapshot: &cdiv1.DataVolumeSourceSnapshot{
-					Namespace: snapshot.Namespace,
-					Name:      snapshot.Name,
-				},
-			}
-			dv := newDataVolumeWithStorageSpec("testDV", snapSource, nil, storage)
-			resp := validateDataVolumeCreateEx(dv, nil, nil, []runtime.Object{snapshot}, nil)
-			Expect(resp.Allowed).To(BeFalse())
-		})
-
-		It("should reject snapshot clone when no input size/recommended restore size", func() {
-			snapshot := &snapshotv1.VolumeSnapshot{
-				ObjectMeta: metav1.ObjectMeta{
-					Name:      "testsnap",
-					Namespace: testNamespace,
-				},
-				Status: &snapshotv1.VolumeSnapshotStatus{},
-			}
-			storage := &cdiv1.StorageSpec{}
-			snapSource := &cdiv1.DataVolumeSource{
-				Snapshot: &cdiv1.DataVolumeSourceSnapshot{
-					Namespace: snapshot.Namespace,
-					Name:      snapshot.Name,
-				},
-			}
-			dv := newDataVolumeWithStorageSpec("testDV", snapSource, nil, storage)
-			resp := validateDataVolumeCreateEx(dv, nil, nil, []runtime.Object{snapshot}, nil)
-			Expect(resp.Allowed).To(BeFalse())
-		})
-
 		DescribeTable("should", func(oldFinalCheckpoint bool, oldCheckpoints []string, newFinalCheckpoint bool, newCheckpoints []string, modifyDV func(*cdiv1.DataVolume), expectedSuccess bool, sourceFunc func() *cdiv1.DataVolumeSource) {
 			oldDV := newMultistageDataVolume("multi-stage", oldFinalCheckpoint, oldCheckpoints, sourceFunc)
 			oldBytes, _ := json.Marshal(&oldDV)
@@ -835,14 +794,14 @@ var _ = Describe("Validating Webhook", func() {
 			Entry("accept DataVolume with PVC and sourceRef missing namespace on create", &emptyNamespace),
 		)
 
-		It("should reject DataVolume with SourceRef on create if DataSource does not exist", func() {
+		It("should allow DataVolume with SourceRef on create if DataSource does not exist", func() {
 			ns := "testNamespace"
 			dataVolume := newDataSourceDataVolume("testDV", &ns, "test")
 			resp := validateDataVolumeCreate(dataVolume)
-			Expect(resp.Allowed).To(BeFalse())
+			Expect(resp.Allowed).To(BeTrue())
 		})
 
-		It("should reject DataVolume with SourceRef on create if DataSource exists but its PVC field is not populated", func() {
+		It("should allow DataVolume with SourceRef on create if DataSource exists but its PVC field is not populated", func() {
 			dataVolume := newDataSourceDataVolume("testDV", &testNamespace, "test")
 			dataSource := &cdiv1.DataSource{
 				ObjectMeta: metav1.ObjectMeta{
@@ -856,7 +815,7 @@ var _ = Describe("Validating Webhook", func() {
 				},
 			}
 			resp := validateDataVolumeCreateEx(dataVolume, nil, []runtime.Object{dataSource}, nil, nil)
-			Expect(resp.Allowed).To(BeFalse())
+			Expect(resp.Allowed).To(BeTrue())
 		})
 
 		It("should accept DataVolume with SourceRef on create if DataSource exists but PVC does not exist", func() {
@@ -1027,7 +986,6 @@ func newPVCDataVolume(name, pvcNamespace, pvcName string) *cdiv1.DataVolume {
 }
 
 func newDataVolumeWithEmptyPVCSpec(name, url string) *cdiv1.DataVolume {
-
 	httpSource := cdiv1.DataVolumeSource{
 		HTTP: &cdiv1.DataVolumeSourceHTTP{URL: url},
 	}
@@ -1195,7 +1153,7 @@ func newPVCSpec(sizeValue int64) *corev1.PersistentVolumeClaimSpec {
 		AccessModes: []corev1.PersistentVolumeAccessMode{
 			corev1.ReadWriteOnce,
 		},
-		Resources: corev1.ResourceRequirements{
+		Resources: corev1.VolumeResourceRequirements{
 			Requests: requests,
 		},
 	}
@@ -1251,7 +1209,7 @@ func validateAdmissionReview(ar *admissionv1.AdmissionReview, objects ...runtime
 
 func serve(ar *admissionv1.AdmissionReview, handler http.Handler) *admissionv1.AdmissionResponse {
 	reqBytes, _ := json.Marshal(ar)
-	req, err := http.NewRequest("POST", "/foobar", bytes.NewReader(reqBytes))
+	req, err := http.NewRequest(http.MethodPost, "/foobar", bytes.NewReader(reqBytes))
 	Expect(err).ToNot(HaveOccurred())
 
 	req.Header.Set("Content-Type", "application/json")
