@@ -5,11 +5,13 @@ import (
 	"fmt"
 
 	"github.com/go-logr/logr"
+	snapshotv1 "github.com/kubernetes-csi/external-snapshotter/client/v6/apis/volumesnapshot/v1"
 
 	corev1 "k8s.io/api/core/v1"
 	storagev1 "k8s.io/api/storage/v1"
 	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/apimachinery/pkg/util/sets"
 	"k8s.io/client-go/tools/record"
 
@@ -128,6 +130,18 @@ func GetGlobalCloneStrategyOverride(ctx context.Context, c client.Client) (*cdiv
 	return cr.Spec.CloneStrategyOverride, nil
 }
 
+// GetSnapshotContentFromSnapshot returns the VolumeSnapshotContent of a given VolumeSnapshot
+func GetSnapshotContentFromSnapshot(ctx context.Context, c client.Client, snapshot *snapshotv1.VolumeSnapshot) (*snapshotv1.VolumeSnapshotContent, error) {
+	if snapshot.Status == nil || snapshot.Status.BoundVolumeSnapshotContentName == nil {
+		return nil, fmt.Errorf("volumeSnapshotContent name not found")
+	}
+	vsc := &snapshotv1.VolumeSnapshotContent{}
+	if err := c.Get(ctx, types.NamespacedName{Name: *snapshot.Status.BoundVolumeSnapshotContentName}, vsc); err != nil {
+		return nil, err
+	}
+	return vsc, nil
+}
+
 // GetStorageClassForClaim returns the storageclass for a PVC
 func GetStorageClassForClaim(ctx context.Context, c client.Client, pvc *corev1.PersistentVolumeClaim) (*storagev1.StorageClass, error) {
 	if pvc.Spec.StorageClassName == nil || *pvc.Spec.StorageClassName == "" {
@@ -269,9 +283,9 @@ func GetCompatibleVolumeSnapshotClass(ctx context.Context, c client.Client, log
 	return cc.GetVolumeSnapshotClass(context.TODO(), c, targetClaim, *driver, snapshotClassName, log, recorder)
 }
 
-// SameVolumeMode returns true if all pvcs have the same volume mode
-func SameVolumeMode(pvc1 *corev1.PersistentVolumeClaim, others ...*corev1.PersistentVolumeClaim) bool {
-	vm := util.ResolveVolumeMode(pvc1.Spec.VolumeMode)
+// SameVolumeMode returns true if all target pvcs have the same volume mode as the source
+func SameVolumeMode(srcVolumeMode *corev1.PersistentVolumeMode, others ...*corev1.PersistentVolumeClaim) bool {
+	vm := util.ResolveVolumeMode(srcVolumeMode)
 	for _, pvc := range others {
 		if util.ResolveVolumeMode(pvc.Spec.VolumeMode) != vm {
 			return false
