@@ -388,6 +388,10 @@ func (p *Planner) computeStrategyForSourceSnapshot(ctx context.Context, args *Ch
 	}
 
 	// Do snapshot and storage class validation
+	vsc, err := GetSnapshotContentFromSnapshot(ctx, p.Client, sourceSnapshot)
+	if err != nil {
+		return nil, err
+	}
 	targetStorageClass, err := GetStorageClassForClaim(ctx, p.Client, args.TargetClaim)
 	if err != nil {
 		return nil, err
@@ -395,7 +399,7 @@ func (p *Planner) computeStrategyForSourceSnapshot(ctx context.Context, args *Ch
 	if targetStorageClass == nil {
 		return nil, fmt.Errorf("target claim's storageclass doesn't exist, clone will not work")
 	}
-	valid, err := cc.ValidateSnapshotCloneProvisioners(ctx, p.Client, sourceSnapshot, targetStorageClass)
+	valid, err := cc.ValidateSnapshotCloneProvisioners(vsc, targetStorageClass)
 	if err != nil {
 		return nil, err
 	}
@@ -405,7 +409,7 @@ func (p *Planner) computeStrategyForSourceSnapshot(ctx context.Context, args *Ch
 		return res, nil
 	}
 
-	// Lastly, do size validation to determine whether to use dumb or smart cloning
+	// do size validation
 	valid, err = cc.ValidateSnapshotCloneSize(sourceSnapshot, &args.TargetClaim.Spec, targetStorageClass, args.Log)
 	if err != nil {
 		return nil, err
@@ -414,6 +418,14 @@ func (p *Planner) computeStrategyForSourceSnapshot(ctx context.Context, args *Ch
 		p.fallbackToHostAssisted(args.TargetClaim, res, NoVolumeExpansion, MessageNoVolumeExpansion)
 		return res, nil
 	}
+
+	// Lastly, do volume mode validation to determine whether to use dumb or smart cloning
+	if !SameVolumeMode(vsc.Spec.SourceVolumeMode, args.TargetClaim) {
+		p.fallbackToHostAssisted(args.TargetClaim, res, IncompatibleVolumeModes, MessageIncompatibleVolumeModes)
+		args.Log.V(3).Info("Volume modes differs, need to fall back to host assisted - Snapshot")
+		return res, nil
+	}
+
 	res.Strategy = cdiv1.CloneStrategySnapshot
 	return res, nil
 }
@@ -469,7 +481,7 @@ func (p *Planner) validateAdvancedClonePVC(ctx context.Context, args *ChooseStra
 		return nil
 	}
 
-	if !SameVolumeMode(sourceClaim, args.TargetClaim) {
+	if !SameVolumeMode(sourceClaim.Spec.VolumeMode, args.TargetClaim) {
 		p.fallbackToHostAssisted(args.TargetClaim, res, IncompatibleVolumeModes, MessageIncompatibleVolumeModes)
 		args.Log.V(3).Info("volume modes not compatible for advanced clone")
 		return nil
@@ -779,11 +791,8 @@ func createDesiredClaim(namespace string, targetClaim *corev1.PersistentVolumeCl
 }
 
 func createTempSourceClaim(ctx context.Context, log logr.Logger, namespace string, targetClaim *corev1.PersistentVolumeClaim, snapshot *snapshotv1.VolumeSnapshot, client client.Client) (*corev1.PersistentVolumeClaim, error) {
-	if snapshot.Status == nil || snapshot.Status.BoundVolumeSnapshotContentName == nil {
-		return nil, fmt.Errorf("volumeSnapshotContent name not found")
-	}
-	vsc := &snapshotv1.VolumeSnapshotContent{}
-	if err := client.Get(ctx, types.NamespacedName{Name: *snapshot.Status.BoundVolumeSnapshotContentName}, vsc); err != nil {
+	vsc, err := GetSnapshotContentFromSnapshot(ctx, client, snapshot)
+	if err != nil {
 		return nil, err
 	}
 	scName, err := getStorageClassNameForTempSourceClaim(ctx, vsc, client)
