@@ -95,8 +95,6 @@ const (
 	// AnnExternalPopulation annotation marks a PVC as "externally populated", allowing the import-controller to skip it
 	AnnExternalPopulation = AnnAPIGroup + "/externalPopulation"
 
-	// AnnDeleteAfterCompletion is PVC annotation for deleting DV after completion
-	AnnDeleteAfterCompletion = AnnAPIGroup + "/storage.deleteAfterCompletion"
 	// AnnPodRetainAfterCompletion is PVC annotation for retaining transfer pods after completion
 	AnnPodRetainAfterCompletion = AnnAPIGroup + "/storage.pod.retainAfterCompletion"
 
@@ -149,6 +147,8 @@ const (
 	AnnVddkHostConnection = AnnAPIGroup + "/storage.pod.vddk.host"
 	// AnnVddkInitImageURL saves a per-DV VDDK image URL on the PVC
 	AnnVddkInitImageURL = AnnAPIGroup + "/storage.pod.vddk.initimageurl"
+	// AnnVddkExtraArgs references a ConfigMap that holds arguments to pass directly to the VDDK library
+	AnnVddkExtraArgs = AnnAPIGroup + "/storage.pod.vddk.extraargs"
 
 	// AnnRequiresScratch provides a const for our PVC requiring scratch annotation
 	AnnRequiresScratch = AnnAPIGroup + "/storage.import.requiresScratch"
@@ -256,9 +256,6 @@ const (
 	// be dynamically provisioned. Its value is the name of the selected node.
 	AnnSelectedNode = "volume.kubernetes.io/selected-node"
 
-	// AnnGarbageCollected is a PVC annotation indicating that the PVC was garbage collected
-	AnnGarbageCollected = AnnAPIGroup + "/garbageCollected"
-
 	// CloneUniqueID is used as a special label to be used when we search for the pod
 	CloneUniqueID = AnnAPIGroup + "/storage.clone.cloneUniqeId"
 
@@ -1419,16 +1416,6 @@ func IsErrCacheNotStarted(err error) bool {
 	return errors.As(err, &target)
 }
 
-// GetDataVolumeTTLSeconds gets the current DataVolume TTL in seconds if GC is enabled, or < 0 if GC is disabled
-// Garbage collection is disabled by default
-func GetDataVolumeTTLSeconds(config *cdiv1.CDIConfig) int32 {
-	const defaultDataVolumeTTLSeconds = -1
-	if config.Spec.DataVolumeTTLSeconds != nil {
-		return *config.Spec.DataVolumeTTLSeconds
-	}
-	return defaultDataVolumeTTLSeconds
-}
-
 // NewImportDataVolume returns new import DataVolume CR
 func NewImportDataVolume(name string) *cdiv1.DataVolume {
 	return &cdiv1.DataVolume{
@@ -1819,19 +1806,12 @@ func ValidateSnapshotCloneSize(snapshot *snapshotv1.VolumeSnapshot, pvcSpec *cor
 }
 
 // ValidateSnapshotCloneProvisioners validates the target PVC storage class against the snapshot class provisioner
-func ValidateSnapshotCloneProvisioners(ctx context.Context, c client.Client, snapshot *snapshotv1.VolumeSnapshot, storageClass *storagev1.StorageClass) (bool, error) {
+func ValidateSnapshotCloneProvisioners(vsc *snapshotv1.VolumeSnapshotContent, storageClass *storagev1.StorageClass) (bool, error) {
 	// Do snapshot and storage class validation
 	if storageClass == nil {
 		return false, fmt.Errorf("target storage class not found")
 	}
-	if snapshot.Status == nil || snapshot.Status.BoundVolumeSnapshotContentName == nil {
-		return false, fmt.Errorf("volumeSnapshotContent name not found")
-	}
-	volumeSnapshotContent := &snapshotv1.VolumeSnapshotContent{}
-	if err := c.Get(ctx, types.NamespacedName{Name: *snapshot.Status.BoundVolumeSnapshotContentName}, volumeSnapshotContent); err != nil {
-		return false, err
-	}
-	if storageClass.Provisioner != volumeSnapshotContent.Spec.Driver {
+	if storageClass.Provisioner != vsc.Spec.Driver {
 		return false, nil
 	}
 	// TODO: get sourceVolumeMode from volumesnapshotcontent and validate against target spec
