@@ -6,10 +6,12 @@ import (
 
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
+
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
+
 	cdiv1 "kubevirt.io/containerized-data-importer-api/pkg/apis/core/v1beta1"
 	sdkapi "kubevirt.io/controller-lifecycle-operator-sdk/api"
 )
@@ -28,36 +30,6 @@ var _ = Describe("GetRequestedImageSize", func() {
 	})
 })
 
-var _ = Describe("validateContentTypes", func() {
-	getContentType := func(contentType string) cdiv1.DataVolumeContentType {
-		if contentType == "" {
-			return cdiv1.DataVolumeKubeVirt
-		}
-		return cdiv1.DataVolumeContentType(contentType)
-	}
-
-	DescribeTable("should return", func(sourceContentType, targetContentType string, expectedResult bool) {
-		sourcePvc := CreatePvc("testPVC", "default", map[string]string{AnnContentType: sourceContentType}, nil)
-		dvSpec := &cdiv1.DataVolumeSpec{}
-		dvSpec.ContentType = cdiv1.DataVolumeContentType(targetContentType)
-
-		validated, sourceContent, targetContent := validateContentTypes(sourcePvc, dvSpec)
-		Expect(validated).To(Equal(expectedResult))
-		Expect(sourceContent).To(Equal(getContentType(sourceContentType)))
-		Expect(targetContent).To(Equal(getContentType(targetContentType)))
-	},
-		Entry("true when using archive in source and target", string(cdiv1.DataVolumeArchive), string(cdiv1.DataVolumeArchive), true),
-		Entry("false when using archive in source and KubeVirt in target", string(cdiv1.DataVolumeArchive), string(cdiv1.DataVolumeKubeVirt), false),
-		Entry("false when using KubeVirt in source and archive in target", string(cdiv1.DataVolumeKubeVirt), string(cdiv1.DataVolumeArchive), false),
-		Entry("true when using KubeVirt in source and target", string(cdiv1.DataVolumeKubeVirt), string(cdiv1.DataVolumeKubeVirt), true),
-		Entry("true when using default in source and target", "", "", true),
-		Entry("true when using default in source and KubeVirt (explicit) in target", "", string(cdiv1.DataVolumeKubeVirt), true),
-		Entry("true when using KubeVirt (explicit) in source and default in target", string(cdiv1.DataVolumeKubeVirt), "", true),
-		Entry("false when using default in source and archive in target", "", string(cdiv1.DataVolumeArchive), false),
-		Entry("false when using archive in source and default in target", string(cdiv1.DataVolumeArchive), "", false),
-	)
-})
-
 var _ = Describe("GetStorageClassByName", func() {
 	It("Should return the default storage class name", func() {
 		client := CreateClient(
@@ -300,6 +272,100 @@ var _ = Describe("Rebind", func() {
 	})
 })
 
+var _ = Describe("GetMetricsURL", func() {
+	makePod := func(ip string, withMetrics bool) *v1.Pod {
+		pod := &v1.Pod{
+			Status: v1.PodStatus{
+				PodIP: ip,
+			},
+		}
+
+		if !withMetrics {
+			return pod
+		}
+
+		pod.Spec = v1.PodSpec{
+			Containers: []v1.Container{
+				{
+					Ports: []v1.ContainerPort{
+						{Name: "metrics", ContainerPort: 8080},
+					},
+				},
+			},
+		}
+
+		return pod
+	}
+
+	It("Should succeed with IPv4", func() {
+		pod := makePod("127.0.0.1", true)
+		url, err := GetMetricsURL(pod)
+		Expect(err).ToNot(HaveOccurred())
+		Expect(url).To(Equal("https://127.0.0.1:8080/metrics"))
+	})
+
+	It("Should succeed with IPv6", func() {
+		pod := makePod("::1", true)
+		url, err := GetMetricsURL(pod)
+		Expect(err).ToNot(HaveOccurred())
+		Expect(url).To(Equal("https://[::1]:8080/metrics"))
+	})
+
+	It("Should fail when there is no metrics port", func() {
+		pod := makePod("127.0.0.1", false)
+		_, err := GetMetricsURL(pod)
+		Expect(err).To(HaveOccurred())
+	})
+})
+
+var _ = Describe("CopyAllowedLabels", func() {
+	const (
+		testKubevirtIoKey               = "test.kubevirt.io/test"
+		testKubevirtIoValue             = "testvalue"
+		testInstancetypeKubevirtIoKey   = "instancetype.kubevirt.io/default-preference"
+		testInstancetypeKubevirtIoValue = "testpreference"
+		testKubevirtIoKeyExisting       = "test.kubevirt.io/existing"
+		testKubevirtIoValueExisting     = "existing"
+		testKubevirtIoNewValueExisting  = "newvalue"
+		testUndesiredKey                = "undesired.key"
+	)
+
+	It("Should copy desired labels", func() {
+		srcLabels := map[string]string{
+			testKubevirtIoKey:             testKubevirtIoValue,
+			testInstancetypeKubevirtIoKey: testInstancetypeKubevirtIoValue,
+			testUndesiredKey:              "undesired.key",
+		}
+		ds := &cdiv1.DataSource{}
+		CopyAllowedLabels(srcLabels, ds, false)
+		Expect(ds.Labels).To(HaveKeyWithValue(testKubevirtIoKey, testKubevirtIoValue))
+		Expect(ds.Labels).To(HaveKeyWithValue(testInstancetypeKubevirtIoKey, testInstancetypeKubevirtIoValue))
+		Expect(ds.Labels).ToNot(HaveKey(testUndesiredKey))
+	})
+
+	DescribeTable("Should overwrite existing labels", func(overwrite bool) {
+		srcLabels := map[string]string{
+			testKubevirtIoKeyExisting: testKubevirtIoNewValueExisting,
+		}
+		ds := &cdiv1.DataSource{
+			ObjectMeta: metav1.ObjectMeta{
+				Labels: map[string]string{
+					testKubevirtIoKeyExisting: testKubevirtIoValueExisting,
+				},
+			},
+		}
+		CopyAllowedLabels(srcLabels, ds, overwrite)
+		if overwrite {
+			Expect(ds.Labels).To(HaveKeyWithValue(testKubevirtIoKeyExisting, testKubevirtIoNewValueExisting))
+		} else {
+			Expect(ds.Labels).To(HaveKeyWithValue(testKubevirtIoKeyExisting, testKubevirtIoValueExisting))
+		}
+	},
+		Entry("when override enabled", true),
+		Entry("not when override disabled", false),
+	)
+})
+
 func createPvcNoSize(name, ns string, annotations, labels map[string]string) *v1.PersistentVolumeClaim {
 	return &v1.PersistentVolumeClaim{
 		ObjectMeta: metav1.ObjectMeta{
