@@ -29,6 +29,7 @@ import (
 	"github.com/google/uuid"
 	snapshotv1 "github.com/kubernetes-csi/external-snapshotter/client/v6/apis/volumesnapshot/v1"
 	imagev1 "github.com/openshift/api/image/v1"
+	secv1 "github.com/openshift/api/security/v1"
 	"github.com/pkg/errors"
 	"github.com/prometheus/client_golang/prometheus"
 
@@ -225,6 +226,7 @@ var _ = Describe("All DataImportCron Tests", func() {
 			Expect(err).ToNot(HaveOccurred())
 			containers := cronjob.Spec.JobTemplate.Spec.Template.Spec.Containers
 			Expect(containers).To(HaveLen(1))
+			Expect(cronjob.Spec.JobTemplate.Spec.Template.GetAnnotations()[secv1.RequiredSCCAnnotation]).To(Equal(common.RestrictedSCCName))
 
 			env := containers[0].Env
 			Expect(getEnvVar(env, common.ImportProxyHTTP)).To(Equal(httpProxy))
@@ -415,6 +417,7 @@ var _ = Describe("All DataImportCron Tests", func() {
 			Expect(podSpec.Affinity).To(Equal(workloads.Affinity))
 			Expect(podSpec.NodeSelector).To(Equal(workloads.NodeSelector))
 			Expect(podSpec.Tolerations).To(Equal(workloads.Tolerations))
+			Expect(job.Spec.Template.GetAnnotations()[secv1.RequiredSCCAnnotation]).To(Equal(common.RestrictedSCCName))
 		})
 
 		It("Should not modify new CronJob on initCronJob", func() {
@@ -837,6 +840,33 @@ var _ = Describe("All DataImportCron Tests", func() {
 			Entry("has no tag", imageStreamName, 1),
 		)
 
+		It("Should fail with non-existing source PVC", func() {
+			cron := newDataImportCron(cronName)
+			cron.Spec.Template.Spec.Source = &cdiv1.DataVolumeSource{
+				PVC: &cdiv1.DataVolumeSourcePVC{
+					Name: "no-such-pvc",
+				},
+			}
+			reconciler = createDataImportCronReconciler(cron)
+			_, err := reconciler.Reconcile(context.TODO(), cronReq)
+			Expect(err).To(HaveOccurred())
+			Expect(err.Error()).To(ContainSubstring("not found"))
+		})
+
+		It("Should succeed with existing source PVC", func() {
+			pvc := newPVC("test-pvc")
+			cron := newDataImportCron(cronName)
+			cron.Spec.Template.Spec.Source = &cdiv1.DataVolumeSource{
+				PVC: &cdiv1.DataVolumeSourcePVC{
+					Name:      pvc.Name,
+					Namespace: pvc.Namespace,
+				},
+			}
+			reconciler = createDataImportCronReconciler(cron, pvc)
+			_, err := reconciler.Reconcile(context.TODO(), cronReq)
+			Expect(err).ToNot(HaveOccurred())
+		})
+
 		It("Should succeed garbage collecting old version DVs", func() {
 			cron = newDataImportCron(cronName)
 			importsToKeep := int32(1)
@@ -1464,6 +1494,15 @@ func newDataImportCronWithImageStream(dataImportCronName, taggedImageStreamName
 	return cron
 }
 
+func newPVC(name string) *corev1.PersistentVolumeClaim {
+	return &corev1.PersistentVolumeClaim{
+		ObjectMeta: metav1.ObjectMeta{
+			Name:      name,
+			Namespace: metav1.NamespaceDefault,
+			UID:       types.UID(metav1.NamespaceDefault + "-" + name),
+		},
+	}
+}
 func newImageStream(name string) *imagev1.ImageStream {
 	return &imagev1.ImageStream{
 		TypeMeta: metav1.TypeMeta{APIVersion: imagev1.SchemeGroupVersion.String()},
