@@ -29,6 +29,7 @@ import (
 	. "github.com/onsi/gomega"
 
 	snapshotv1 "github.com/kubernetes-csi/external-snapshotter/client/v6/apis/volumesnapshot/v1"
+
 	corev1 "k8s.io/api/core/v1"
 	storagev1 "k8s.io/api/storage/v1"
 	extv1 "k8s.io/apiextensions-apiserver/pkg/apis/apiextensions/v1"
@@ -39,7 +40,9 @@ import (
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/client-go/kubernetes/scheme"
 	"k8s.io/client-go/tools/record"
-	"k8s.io/utils/pointer"
+	"k8s.io/utils/ptr"
+
+	"sigs.k8s.io/controller-runtime/pkg/client"
 	"sigs.k8s.io/controller-runtime/pkg/client/fake"
 	logf "sigs.k8s.io/controller-runtime/pkg/log"
 	"sigs.k8s.io/controller-runtime/pkg/reconcile"
@@ -102,7 +105,7 @@ var _ = Describe("All DataVolume Tests", func() {
 			Expect(event).To(ContainSubstring(MessageErrStorageClassNotFound))
 		},
 			Entry("no StorageClassName, and no default storage class set", nil),
-			Entry("non-existing StorageClassName", pointer.String("nosuch")),
+			Entry("non-existing StorageClassName", ptr.To[string]("nosuch")),
 		)
 
 		It("Should create volumeImportSource if should use cdi populator", func() {
@@ -159,8 +162,16 @@ var _ = Describe("All DataVolume Tests", func() {
 			Expect(err).ToNot(HaveOccurred())
 			Expect(dv.GetAnnotations()[AnnUsePopulator]).To(Equal("true"))
 
+			pvc := &corev1.PersistentVolumeClaim{}
+			err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}, pvc)
+			Expect(err).ToNot(HaveOccurred())
+
+			pvc.Annotations[AnnPodPhase] = string(corev1.PodSucceeded)
+			err = reconciler.client.Update(context.TODO(), pvc)
+			Expect(err).ToNot(HaveOccurred())
+
 			dv.Status.Phase = cdiv1.Succeeded
-			err = reconciler.client.Update(context.TODO(), dv)
+			err = reconciler.client.Status().Update(context.TODO(), dv)
 			Expect(err).ToNot(HaveOccurred())
 
 			_, err = reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}})
@@ -173,7 +184,8 @@ var _ = Describe("All DataVolume Tests", func() {
 		})
 
 		It("Should create a PVC on a valid import DV", func() {
-			reconciler = createImportReconciler(NewImportDataVolume("test-dv"))
+			dv := NewImportDataVolume("test-dv")
+			reconciler = createImportReconciler(dv)
 			_, err := reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}})
 			Expect(err).ToNot(HaveOccurred())
 			pvc := &corev1.PersistentVolumeClaim{}
@@ -182,6 +194,35 @@ var _ = Describe("All DataVolume Tests", func() {
 			Expect(pvc.Name).To(Equal("test-dv"))
 			Expect(pvc.Labels[common.AppKubernetesPartOfLabel]).To(Equal("testing"))
 			Expect(pvc.Labels[common.KubePersistentVolumeFillingUpSuppressLabelKey]).To(Equal(common.KubePersistentVolumeFillingUpSuppressLabelValue))
+			val, ok := pvc.Annotations[AnnCreatedForDataVolume]
+			Expect(ok).To(BeTrue())
+			Expect(val).To(Equal(string(dv.UID)))
+		})
+
+		It("Should create a PVC on a valid import DV without delayed annotation then add on success", func() {
+			dv := NewImportDataVolume("test-dv")
+			AddAnnotation(dv, "foo", "bar")
+			AddAnnotation(dv, AnnPopulatedFor, "true")
+			reconciler = createImportReconciler(dv)
+			_, err := reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}})
+			Expect(err).ToNot(HaveOccurred())
+			pvc := &corev1.PersistentVolumeClaim{}
+			err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}, pvc)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(pvc.Annotations["foo"]).To(Equal("bar"))
+			Expect(pvc.Annotations).ToNot(HaveKey(AnnPopulatedFor))
+
+			err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}, dv)
+			Expect(err).ToNot(HaveOccurred())
+			dv.Status.Phase = cdiv1.Succeeded
+			err = reconciler.client.Status().Update(context.Background(), dv)
+			Expect(err).ToNot(HaveOccurred())
+			_, err = reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}})
+			Expect(err).ToNot(HaveOccurred())
+			err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}, pvc)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(pvc.Annotations["foo"]).To(Equal("bar"))
+			Expect(pvc.Annotations[AnnPopulatedFor]).To(Equal("true"))
 		})
 
 		It("Should fail if dv source not import when use populators", func() {
@@ -352,7 +393,7 @@ var _ = Describe("All DataVolume Tests", func() {
 			importDataVolume := newImportDataVolumeWithPvc("test-dv", nil)
 			// spec with accessMode/VolumeMode so storageprofile is not needed
 			importDataVolume.Spec.Storage = createStorageSpec()
-			importDataVolume.Spec.Storage.Resources = corev1.ResourceRequirements{}
+			importDataVolume.Spec.Storage.Resources = corev1.VolumeResourceRequirements{}
 			defaultStorageClass := CreateStorageClass("defaultSc", map[string]string{AnnDefaultStorageClass: "true"})
 			reconciler = createImportReconciler(defaultStorageClass, importDataVolume)
 
@@ -366,7 +407,7 @@ var _ = Describe("All DataVolume Tests", func() {
 			importDataVolume := newImportDataVolumeWithPvc("test-dv", nil)
 			// spec with accessMode/VolumeMode so storageprofile is not needed
 			importDataVolume.Spec.Storage = createStorageSpec()
-			importDataVolume.Spec.Storage.Resources = corev1.ResourceRequirements{}
+			importDataVolume.Spec.Storage.Resources = corev1.VolumeResourceRequirements{}
 			importDataVolume.Spec.Storage.StorageClassName = &storageClassName
 			defaultStorageClass := CreateStorageClass(storageClassName, map[string]string{AnnDefaultStorageClass: "true"})
 			reconciler = createImportReconciler(defaultStorageClass, importDataVolume)
@@ -383,7 +424,7 @@ var _ = Describe("All DataVolume Tests", func() {
 			importDataVolume.Spec.ContentType = contentType
 			importDataVolume.Spec.Storage = &cdiv1.StorageSpec{
 				StorageClassName: &scName,
-				Resources: corev1.ResourceRequirements{
+				Resources: corev1.VolumeResourceRequirements{
 					Requests: corev1.ResourceList{
 						corev1.ResourceStorage: resource.MustParse("1G"),
 					},
@@ -426,7 +467,7 @@ var _ = Describe("All DataVolume Tests", func() {
 			importDataVolume.Spec.Storage = &cdiv1.StorageSpec{
 				StorageClassName: &scName,
 				VolumeMode:       &BlockMode,
-				Resources: corev1.ResourceRequirements{
+				Resources: corev1.VolumeResourceRequirements{
 					Requests: corev1.ResourceList{
 						corev1.ResourceStorage: resource.MustParse("1G"),
 					},
@@ -443,10 +484,10 @@ var _ = Describe("All DataVolume Tests", func() {
 
 			_, err := reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}})
 			Expect(err).To(HaveOccurred())
-			Expect(err.Error()).To(ContainSubstring("DataVolume with ContentType Archive cannot have block volumeMode"))
+			Expect(err.Error()).To(ContainSubstring("ContentType Archive cannot have block volumeMode"))
 			By("Checking error event recorded")
 			event := <-reconciler.recorder.(*record.FakeRecorder).Events
-			Expect(event).To(ContainSubstring("DataVolume with ContentType Archive cannot have block volumeMode"))
+			Expect(event).To(ContainSubstring("ContentType Archive cannot have block volumeMode"))
 		})
 
 		It("Should set on a PVC matching access mode from storageProfile to the DV given volume mode", func() {
@@ -455,7 +496,7 @@ var _ = Describe("All DataVolume Tests", func() {
 			importDataVolume.Spec.Storage = &cdiv1.StorageSpec{
 				StorageClassName: &scName,
 				VolumeMode:       &FilesystemMode,
-				Resources: corev1.ResourceRequirements{
+				Resources: corev1.VolumeResourceRequirements{
 					Requests: corev1.ResourceList{
 						corev1.ResourceStorage: resource.MustParse("1G"),
 					},
@@ -488,7 +529,7 @@ var _ = Describe("All DataVolume Tests", func() {
 			importDataVolume := newImportDataVolumeWithPvc("test-dv", nil)
 			importDataVolume.Spec.Storage = &cdiv1.StorageSpec{
 				StorageClassName: &scName,
-				Resources: corev1.ResourceRequirements{
+				Resources: corev1.VolumeResourceRequirements{
 					Requests: corev1.ResourceList{
 						corev1.ResourceStorage: resource.MustParse("1G"),
 					},
@@ -527,7 +568,7 @@ var _ = Describe("All DataVolume Tests", func() {
 			importDataVolume.Spec.Storage = &cdiv1.StorageSpec{
 				StorageClassName: &scName,
 				AccessModes:      []corev1.PersistentVolumeAccessMode{corev1.ReadWriteOnce},
-				Resources: corev1.ResourceRequirements{
+				Resources: corev1.VolumeResourceRequirements{
 					Requests: corev1.ResourceList{
 						corev1.ResourceStorage: resource.MustParse("1G"),
 					},
@@ -560,7 +601,7 @@ var _ = Describe("All DataVolume Tests", func() {
 			importDataVolume := newImportDataVolumeWithPvc("test-dv", nil)
 			importDataVolume.Spec.Storage = &cdiv1.StorageSpec{
 				StorageClassName: &scName,
-				Resources: corev1.ResourceRequirements{
+				Resources: corev1.VolumeResourceRequirements{
 					Requests: corev1.ResourceList{
 						corev1.ResourceStorage: resource.MustParse("1G"),
 					},
@@ -597,7 +638,7 @@ var _ = Describe("All DataVolume Tests", func() {
 			scName := "testStorageClass"
 			importDataVolume := newImportDataVolumeWithPvc("test-dv", nil)
 			importDataVolume.Spec.Storage = &cdiv1.StorageSpec{
-				Resources: corev1.ResourceRequirements{
+				Resources: corev1.VolumeResourceRequirements{
 					Requests: corev1.ResourceList{
 						corev1.ResourceStorage: resource.MustParse("1G"),
 					},
@@ -636,7 +677,8 @@ var _ = Describe("All DataVolume Tests", func() {
 			dv.GetAnnotations()["test-ann-2"] = "test-value-2"
 			dv.GetAnnotations()[AnnSource] = "invalid phase should not copy"
 			dv.GetAnnotations()[AnnPodNetwork] = "data-network"
-			dv.GetAnnotations()[AnnPodSidecarInjection] = "false"
+			dv.GetAnnotations()[AnnPodSidecarInjectionIstio] = "false"
+			dv.GetAnnotations()[AnnPodSidecarInjectionLinkerd] = "false"
 			dv.SetLabels(make(map[string]string))
 			dv.GetLabels()["test"] = "test-label"
 			reconciler = createImportReconciler(dv)
@@ -651,7 +693,8 @@ var _ = Describe("All DataVolume Tests", func() {
 			Expect(pvc.GetAnnotations()["test-ann-2"]).To(Equal("test-value-2"))
 			Expect(pvc.GetAnnotations()[AnnSource]).To(Equal(SourceHTTP))
 			Expect(pvc.GetAnnotations()[AnnPodNetwork]).To(Equal("data-network"))
-			Expect(pvc.GetAnnotations()[AnnPodSidecarInjection]).To(Equal("false"))
+			Expect(pvc.GetAnnotations()[AnnPodSidecarInjectionIstio]).To(Equal("false"))
+			Expect(pvc.GetAnnotations()[AnnPodSidecarInjectionLinkerd]).To(Equal("false"))
 			Expect(pvc.GetAnnotations()[AnnPriorityClassName]).To(Equal("p0"))
 			Expect(pvc.Labels["test"]).To(Equal("test-label"))
 		})
@@ -691,7 +734,7 @@ var _ = Describe("All DataVolume Tests", func() {
 			Expect(dv.Status.Phase).To(BeEquivalentTo(""))
 
 			pvc.Status.Phase = corev1.ClaimPending
-			err = reconciler.client.Update(context.TODO(), pvc)
+			err = reconciler.client.Status().Update(context.TODO(), pvc)
 			Expect(err).ToNot(HaveOccurred())
 
 			_, err = reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}})
@@ -761,6 +804,76 @@ var _ = Describe("All DataVolume Tests", func() {
 			Expect(string(dv.Status.Progress)).To(Equal("N/A"))
 		})
 
+		It("Should adopt a PVC (with annotation)", func() {
+			pvc := CreatePvc("test-dv", metav1.NamespaceDefault, nil, nil)
+			pvc.Status.Phase = corev1.ClaimBound
+			dv := NewImportDataVolume("test-dv")
+			AddAnnotation(dv, AnnAllowClaimAdoption, "true")
+			reconciler = createImportReconciler(pvc, dv)
+			_, err := reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}})
+			Expect(err).ToNot(HaveOccurred())
+
+			err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}, pvc)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(pvc.OwnerReferences).To(HaveLen(1))
+			or := pvc.OwnerReferences[0]
+			Expect(or.UID).To(Equal(dv.UID))
+
+			err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}, dv)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(dv.Status.Phase).To(Equal(cdiv1.Succeeded))
+			Expect(string(dv.Status.Progress)).To(Equal("N/A"))
+			_, ok := pvc.Annotations[AnnCreatedForDataVolume]
+			Expect(ok).To(BeFalse())
+		})
+
+		It("Should adopt a unbound PVC (with annotation)", func() {
+			pvc := CreatePvc("test-dv", metav1.NamespaceDefault, nil, nil)
+			pvc.Spec.VolumeName = ""
+			pvc.Status.Phase = corev1.ClaimPending
+			dv := NewImportDataVolume("test-dv")
+			AddAnnotation(dv, AnnAllowClaimAdoption, "true")
+			reconciler = createImportReconciler(pvc, dv)
+			_, err := reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}})
+			Expect(err).ToNot(HaveOccurred())
+
+			err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}, pvc)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(pvc.OwnerReferences).To(HaveLen(1))
+			or := pvc.OwnerReferences[0]
+			Expect(or.UID).To(Equal(dv.UID))
+
+			err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}, dv)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(dv.Status.Phase).To(Equal(cdiv1.Succeeded))
+			Expect(string(dv.Status.Progress)).To(Equal("N/A"))
+			_, ok := pvc.Annotations[AnnCreatedForDataVolume]
+			Expect(ok).To(BeFalse())
+		})
+
+		It("Should adopt a PVC (with featuregate)", func() {
+			pvc := CreatePvc("test-dv", metav1.NamespaceDefault, nil, nil)
+			pvc.Status.Phase = corev1.ClaimBound
+			dv := NewImportDataVolume("test-dv")
+			featureGates := []string{featuregates.DataVolumeClaimAdoption, featuregates.HonorWaitForFirstConsumer}
+			reconciler = createImportReconcilerWithFeatureGates(featureGates, pvc, dv)
+			_, err := reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}})
+			Expect(err).ToNot(HaveOccurred())
+
+			err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}, pvc)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(pvc.OwnerReferences).To(HaveLen(1))
+			or := pvc.OwnerReferences[0]
+			Expect(or.UID).To(Equal(dv.UID))
+
+			err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}, dv)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(dv.Status.Phase).To(Equal(cdiv1.Succeeded))
+			Expect(string(dv.Status.Progress)).To(Equal("N/A"))
+			_, ok := pvc.Annotations[AnnCreatedForDataVolume]
+			Expect(ok).To(BeFalse())
+		})
+
 		It("Should set multistage migration annotations on a newly created PVC", func() {
 			dv := NewImportDataVolume("test-dv")
 			dv.Spec.Checkpoints = []cdiv1.DataVolumeCheckpoint{
@@ -842,7 +955,6 @@ var _ = Describe("All DataVolume Tests", func() {
 
 		DescribeTable("After successful checkpoint copy", func(finalCheckpoint bool, modifyAnnotations func(annotations map[string]string), validate func(pv *corev1.PersistentVolumeClaim, dv *cdiv1.DataVolume)) {
 			annotations := map[string]string{
-				AnnPopulatedFor:       "test-dv",
 				AnnPreviousCheckpoint: "previous",
 				AnnCurrentCheckpoint:  "current",
 				AnnFinalCheckpoint:    strconv.FormatBool(finalCheckpoint),
@@ -880,6 +992,16 @@ var _ = Describe("All DataVolume Tests", func() {
 			}
 			dv.Spec.FinalCheckpoint = finalCheckpoint
 
+			pvc.OwnerReferences = []metav1.OwnerReference{
+				{
+					APIVersion: "cdi.kubevirt.io/v1beta1",
+					Kind:       "DataVolume",
+					Name:       dv.Name,
+					UID:        dv.UID,
+					Controller: ptr.To(true),
+				},
+			}
+
 			reconciler = createImportReconciler(dv, pvc)
 			_, err := reconciler.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}})
 			Expect(err).ToNot(HaveOccurred())
@@ -977,7 +1099,7 @@ var _ = Describe("All DataVolume Tests", func() {
 			err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}, dv)
 			Expect(err).ToNot(HaveOccurred())
 			dv.Status.Phase = current
-			err = reconciler.client.Update(context.TODO(), dv)
+			err = reconciler.client.Status().Update(context.TODO(), dv)
 			Expect(err).ToNot(HaveOccurred())
 
 			pvc := &corev1.PersistentVolumeClaim{}
@@ -995,7 +1117,7 @@ var _ = Describe("All DataVolume Tests", func() {
 			Expect(dv.Status.Phase).To(Equal(expected))
 			Expect(dv.Status.Conditions).To(HaveLen(3))
 			boundCondition := FindConditionByType(cdiv1.DataVolumeBound, dv.Status.Conditions)
-			Expect(boundCondition.Status).To(Equal(corev1.ConditionUnknown))
+			Expect(boundCondition.Status).To(Equal(corev1.ConditionFalse))
 			Expect(boundCondition.Message).To(Equal("No PVC found"))
 
 			By("Checking events recorded")
@@ -1026,7 +1148,7 @@ var _ = Describe("All DataVolume Tests", func() {
 			Expect(err).ToNot(HaveOccurred())
 			Expect(pvc.Name).To(Equal("test-dv"))
 			pvc.Status.Phase = corev1.ClaimPending
-			err = reconciler.client.Update(context.TODO(), pvc)
+			err = reconciler.client.Status().Update(context.TODO(), pvc)
 			Expect(err).ToNot(HaveOccurred())
 			_, err = reconciler.updateStatus(getReconcileRequest(dv), nil, reconciler)
 			Expect(err).ToNot(HaveOccurred())
@@ -1068,7 +1190,7 @@ var _ = Describe("All DataVolume Tests", func() {
 			Expect(err).ToNot(HaveOccurred())
 			Expect(pvc.Name).To(Equal("test-dv"))
 			pvc.Status.Phase = corev1.ClaimPending
-			err = reconciler.client.Update(context.TODO(), pvc)
+			err = reconciler.client.Status().Update(context.TODO(), pvc)
 			Expect(err).ToNot(HaveOccurred())
 			_, err = reconciler.updateStatus(getReconcileRequest(dv), nil, reconciler)
 			Expect(err).ToNot(HaveOccurred())
@@ -1113,7 +1235,7 @@ var _ = Describe("All DataVolume Tests", func() {
 			Expect(err).ToNot(HaveOccurred())
 			Expect(pvc.Name).To(Equal("test-dv"))
 			pvc.Status.Phase = corev1.ClaimPending
-			err = reconciler.client.Update(context.TODO(), pvc)
+			err = reconciler.client.Status().Update(context.TODO(), pvc)
 			Expect(err).ToNot(HaveOccurred())
 			_, err = reconciler.updateStatus(getReconcileRequest(dv), nil, reconciler)
 			Expect(err).ToNot(HaveOccurred())
@@ -1161,7 +1283,7 @@ var _ = Describe("All DataVolume Tests", func() {
 			Expect(err).ToNot(HaveOccurred())
 			Expect(pvc.Name).To(Equal("test-dv"))
 			pvc.Status.Phase = corev1.ClaimPending
-			err = reconciler.client.Update(context.TODO(), pvc)
+			err = reconciler.client.Status().Update(context.TODO(), pvc)
 			Expect(err).ToNot(HaveOccurred())
 			_, err = reconciler.updateStatus(getReconcileRequest(dv), nil, reconciler)
 			Expect(err).ToNot(HaveOccurred())
@@ -1206,10 +1328,12 @@ var _ = Describe("All DataVolume Tests", func() {
 			err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}, pvc)
 			Expect(err).ToNot(HaveOccurred())
 			Expect(pvc.Name).To(Equal("test-dv"))
-			pvc.Status.Phase = corev1.ClaimPending
 			AddAnnotation(pvc, AnnSelectedNode, "node01")
 			err = reconciler.client.Update(context.TODO(), pvc)
 			Expect(err).ToNot(HaveOccurred())
+			pvc.Status.Phase = corev1.ClaimPending
+			err = reconciler.client.Status().Update(context.TODO(), pvc)
+			Expect(err).ToNot(HaveOccurred())
 
 			// Creating a valid PVC Prime
 			pvcPrime := &corev1.PersistentVolumeClaim{}
@@ -1293,11 +1417,13 @@ var _ = Describe("All DataVolume Tests", func() {
 			err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}, pvc)
 			Expect(err).ToNot(HaveOccurred())
 			Expect(pvc.Name).To(Equal("test-dv"))
-			pvc.Status.Phase = corev1.ClaimPending
 			pvc.SetAnnotations(make(map[string]string))
 			pvc.GetAnnotations()[AnnPodPhase] = string(corev1.PodSucceeded)
 			err = reconciler.client.Update(context.TODO(), pvc)
 			Expect(err).ToNot(HaveOccurred())
+			pvc.Status.Phase = corev1.ClaimPending
+			err = reconciler.client.Status().Update(context.TODO(), pvc)
+			Expect(err).ToNot(HaveOccurred())
 			_, err = reconciler.updateStatus(getReconcileRequest(dv), nil, reconciler)
 			Expect(err).ToNot(HaveOccurred())
 			dv = &cdiv1.DataVolume{}
@@ -1339,12 +1465,14 @@ var _ = Describe("All DataVolume Tests", func() {
 			err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}, pvc)
 			Expect(err).ToNot(HaveOccurred())
 			Expect(pvc.Name).To(Equal("test-dv"))
-			pvc.Status.Phase = corev1.ClaimPending
 			pvc.SetAnnotations(make(map[string]string))
 			pvc.GetAnnotations()[AnnCurrentCheckpoint] = "current"
 			pvc.GetAnnotations()[AnnPodPhase] = string(corev1.PodSucceeded)
 			err = reconciler.client.Update(context.TODO(), pvc)
 			Expect(err).ToNot(HaveOccurred())
+			pvc.Status.Phase = corev1.ClaimPending
+			err = reconciler.client.Status().Update(context.TODO(), pvc)
+			Expect(err).ToNot(HaveOccurred())
 			_, err = reconciler.updateStatus(getReconcileRequest(dv), nil, reconciler)
 			Expect(err).ToNot(HaveOccurred())
 			dv = &cdiv1.DataVolume{}
@@ -1374,7 +1502,7 @@ var _ = Describe("All DataVolume Tests", func() {
 			Expect(readyCondition.Message).To(Equal(""))
 		})
 
-		DescribeTable("DV phase", func(testDv runtime.Object, current, expected cdiv1.DataVolumePhase, pvcPhase corev1.PersistentVolumeClaimPhase, podPhase corev1.PodPhase, ann, expectedEvent string, extraAnnotations ...string) {
+		DescribeTable("DV phase", func(testDv client.Object, current, expected cdiv1.DataVolumePhase, pvcPhase corev1.PersistentVolumeClaimPhase, podPhase corev1.PodPhase, ann, expectedEvent string, extraAnnotations ...string) {
 			// First we test the non-populator flow
 			scName := "testpvc"
 			sc := CreateStorageClassWithProvisioner(scName, map[string]string{AnnDefaultStorageClass: "true"}, map[string]string{}, "csi-plugin")
@@ -1531,13 +1659,13 @@ var _ = Describe("All DataVolume Tests", func() {
 		It("Should properly update progress if http endpoint returns matching data", func() {
 			dv.SetUID("b856691e-1038-11e9-a5ab-525500d15501")
 			ts := httptest.NewTLSServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
-				_, _ = fmt.Fprintf(w, "import_progress{ownerUID=\"%v\"} 13.45", dv.GetUID()) // ignore error here
-				w.WriteHeader(200)
+				_, _ = fmt.Fprintf(w, "kubevirt_cdi_import_progress_total{ownerUID=\"%v\"} 13.45", dv.GetUID()) // ignore error here
+				w.WriteHeader(http.StatusOK)
 			}))
 			defer ts.Close()
 			ep, err := url.Parse(ts.URL)
 			Expect(err).ToNot(HaveOccurred())
-			port, err := strconv.Atoi(ep.Port())
+			port, err := strconv.ParseInt(ep.Port(), 10, 32)
 			Expect(err).ToNot(HaveOccurred())
 			pod.Spec.Containers[0].Ports[0].ContainerPort = int32(port)
 			pod.Status.PodIP = ep.Hostname()
@@ -1551,12 +1679,12 @@ var _ = Describe("All DataVolume Tests", func() {
 			dv.Status.Progress = cdiv1.DataVolumeProgress("2.3%")
 			ts := httptest.NewTLSServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 				_, _ = w.Write([]byte(fmt.Sprintf("import_progress{ownerUID=\"%v\"} 13.45", "b856691e-1038-11e9-a5ab-55500d15501")))
-				w.WriteHeader(200)
+				w.WriteHeader(http.StatusOK)
 			}))
 			defer ts.Close()
 			ep, err := url.Parse(ts.URL)
 			Expect(err).ToNot(HaveOccurred())
-			port, err := strconv.Atoi(ep.Port())
+			port, err := strconv.ParseInt(ep.Port(), 10, 32)
 			Expect(err).ToNot(HaveOccurred())
 			pod.Spec.Containers[0].Ports[0].ContainerPort = int32(port)
 			pod.Status.PodIP = ep.Hostname()
@@ -1574,7 +1702,7 @@ var _ = Describe("All DataVolume Tests", func() {
 		largeOverhead   = float64(0.75)
 	)
 	DescribeTable("GetRequiredSpace should return properly enlarged sizes,", func(imageSize int64, overhead float64) {
-		for testedSize := int64(imageSize - 1024); testedSize < imageSize+1024; testedSize++ {
+		for testedSize := imageSize - 1024; testedSize < imageSize+1024; testedSize++ {
 			alignedImageSpace := imageSize
 			if testedSize > imageSize {
 				alignedImageSpace = imageSize + Mi
@@ -1605,25 +1733,6 @@ var _ = Describe("All DataVolume Tests", func() {
 		Entry("40Gi virtual size, large overhead to be 40Gi if <= 40Gi and 41Gi if > 40Gi", 40*Gi, largeOverhead),
 	)
 
-	Describe("DataVolume garbage collection", func() {
-		It("updatePvcOwnerRefs should correctly update PVC owner refs", func() {
-			ref := func(uid string) metav1.OwnerReference {
-				return metav1.OwnerReference{UID: types.UID(uid)}
-			}
-			dv := NewImportDataVolume("test-dv")
-			vmOwnerRef := metav1.OwnerReference{Kind: "VirtualMachine", Name: "test-vm", UID: "test-vm-uid"}
-			dv.OwnerReferences = append(dv.OwnerReferences, ref("3"), vmOwnerRef, ref("2"), ref("1"))
-
-			pvc := CreatePvc("test-dv", metav1.NamespaceDefault, nil, nil)
-			dvOwnerRef := metav1.OwnerReference{Kind: "DataVolume", Name: "test-dv", UID: dv.UID}
-			pvc.OwnerReferences = append(pvc.OwnerReferences, ref("1"), dvOwnerRef, ref("2"))
-
-			updatePvcOwnerRefs(pvc, dv)
-			Expect(pvc.OwnerReferences).To(HaveLen(4))
-			Expect(pvc.OwnerReferences).To(Equal([]metav1.OwnerReference{ref("1"), ref("2"), ref("3"), vmOwnerRef}))
-		})
-	})
-
 	var _ = Describe("shouldUseCDIPopulator", func() {
 		scName := "test"
 		sc := CreateStorageClassWithProvisioner(scName, map[string]string{
@@ -1751,14 +1860,13 @@ func dvPhaseTest(reconciler ReconcilerBase, dvc dvController, testDv runtime.Obj
 	err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}, dv)
 	Expect(err).ToNot(HaveOccurred())
 	dv.Status.Phase = current
-	err = reconciler.client.Update(context.TODO(), dv)
+	err = reconciler.client.Status().Update(context.TODO(), dv)
 	Expect(err).ToNot(HaveOccurred())
 
 	pvc := &corev1.PersistentVolumeClaim{}
 	err = reconciler.client.Get(context.TODO(), types.NamespacedName{Name: "test-dv", Namespace: metav1.NamespaceDefault}, pvc)
 	Expect(err).ToNot(HaveOccurred())
 	Expect(pvc.Name).To(Equal("test-dv"))
-	pvc.Status.Phase = pvcPhase
 	pvc.SetAnnotations(make(map[string]string))
 	pvc.GetAnnotations()[ann] = "something"
 	pvc.GetAnnotations()[AnnPodPhase] = string(podPhase)
@@ -1767,6 +1875,9 @@ func dvPhaseTest(reconciler ReconcilerBase, dvc dvController, testDv runtime.Obj
 	}
 	err = reconciler.client.Update(context.TODO(), pvc)
 	Expect(err).ToNot(HaveOccurred())
+	pvc.Status.Phase = pvcPhase
+	err = reconciler.client.Status().Update(context.TODO(), pvc)
+	Expect(err).ToNot(HaveOccurred())
 
 	_, err = reconciler.updateStatus(getReconcileRequest(dv), nil, dvc)
 	Expect(err).ToNot(HaveOccurred())
@@ -1798,7 +1909,7 @@ func createStorageSpec() *cdiv1.StorageSpec {
 	return &cdiv1.StorageSpec{
 		AccessModes: []corev1.PersistentVolumeAccessMode{corev1.ReadWriteOnce},
 		VolumeMode:  &BlockMode,
-		Resources: corev1.ResourceRequirements{
+		Resources: corev1.VolumeResourceRequirements{
 			Requests: corev1.ResourceList{
 				corev1.ResourceStorage: resource.MustParse("1G"),
 			},
@@ -1841,36 +1952,29 @@ func readyStatusByPhase(phase cdiv1.DataVolumePhase) corev1.ConditionStatus {
 	}
 }
 
-func createImportReconcilerWFFCDisabled(objects ...runtime.Object) *ImportReconciler {
+func createImportReconcilerWFFCDisabled(objects ...client.Object) *ImportReconciler {
+	return createImportReconcilerWithFeatureGates(nil, objects...)
+}
+func createImportReconciler(objects ...client.Object) *ImportReconciler {
+	return createImportReconcilerWithFeatureGates([]string{featuregates.HonorWaitForFirstConsumer}, objects...)
+}
+
+func createImportReconcilerWithFeatureGates(featureGates []string, objects ...client.Object) *ImportReconciler {
 	cdiConfig := MakeEmptyCDIConfigSpec(common.ConfigName)
 	cdiConfig.Status = cdiv1.CDIConfigStatus{
 		ScratchSpaceStorageClass: testStorageClass,
 	}
-	cdiConfig.Spec.FeatureGates = []string{}
+	cdiConfig.Spec.FeatureGates = featureGates
 
-	objs := []runtime.Object{}
+	objs := []client.Object{}
 	objs = append(objs, objects...)
 	objs = append(objs, cdiConfig)
 
 	return createImportReconcilerWithoutConfig(objs...)
 }
 
-func createImportReconciler(objects ...runtime.Object) *ImportReconciler {
-	cdiConfig := MakeEmptyCDIConfigSpec(common.ConfigName)
-	cdiConfig.Status = cdiv1.CDIConfigStatus{
-		ScratchSpaceStorageClass: testStorageClass,
-	}
-	cdiConfig.Spec.FeatureGates = []string{featuregates.HonorWaitForFirstConsumer}
-
-	objs := []runtime.Object{}
-	objs = append(objs, objects...)
-	objs = append(objs, cdiConfig)
-
-	return createImportReconcilerWithoutConfig(objs...)
-}
-
-func createImportReconcilerWithoutConfig(objects ...runtime.Object) *ImportReconciler {
-	objs := []runtime.Object{}
+func createImportReconcilerWithoutConfig(objects ...client.Object) *ImportReconciler {
+	objs := []client.Object{}
 	objs = append(objs, objects...)
 
 	// Register operator types with the runtime scheme.
@@ -1883,7 +1987,8 @@ func createImportReconcilerWithoutConfig(objects ...runtime.Object) *ImportRecon
 
 	builder := fake.NewClientBuilder().
 		WithScheme(s).
-		WithRuntimeObjects(objs...)
+		WithObjects(objs...).
+		WithStatusSubresource(objs...)
 
 	for _, ia := range getIndexArgs() {
 		builder = builder.WithIndex(ia.obj, ia.field, ia.extractValue)
@@ -1958,6 +2063,7 @@ func newUploadDataVolume(name string) *cdiv1.DataVolume {
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      name,
 			Namespace: metav1.NamespaceDefault,
+			UID:       types.UID("uid"),
 		},
 		Spec: cdiv1.DataVolumeSpec{
 			Source: &cdiv1.DataVolumeSource{
