@@ -7,8 +7,8 @@ import (
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 
-	"sigs.k8s.io/controller-runtime/pkg/client"
-	"sigs.k8s.io/controller-runtime/pkg/client/fake"
+	snapshotv1 "github.com/kubernetes-csi/external-snapshotter/client/v6/apis/volumesnapshot/v1"
+	ocpconfigv1 "github.com/openshift/api/config/v1"
 
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
@@ -17,10 +17,11 @@ import (
 	"k8s.io/client-go/kubernetes/scheme"
 	"k8s.io/utils/ptr"
 
+	"sigs.k8s.io/controller-runtime/pkg/client"
+	"sigs.k8s.io/controller-runtime/pkg/client/fake"
+
 	cdiv1 "kubevirt.io/containerized-data-importer-api/pkg/apis/core/v1beta1"
 	. "kubevirt.io/containerized-data-importer/pkg/controller/common"
-
-	ocpconfigv1 "github.com/openshift/api/config/v1"
 )
 
 var _ = Describe("renderPvcSpecVolumeSize", func() {
@@ -46,12 +47,28 @@ var _ = Describe("renderPvcSpecVolumeSize", func() {
 		Expect(found).To(BeFalse())
 	})
 
+	It("Should return error on PVC with storage size smaller than 1MiB", func() {
+		volumeMode := corev1.PersistentVolumeBlock
+		pvcSpec := &corev1.PersistentVolumeClaimSpec{
+			StorageClassName: &scName,
+			VolumeMode:       &volumeMode,
+			Resources: corev1.VolumeResourceRequirements{
+				Requests: corev1.ResourceList{
+					corev1.ResourceStorage: resource.MustParse("9"),
+				},
+			},
+		}
+		err := renderPvcSpecVolumeSize(client, pvcSpec, false)
+		Expect(err).To(HaveOccurred())
+		Expect(err.Error()).To(ContainSubstring("PVC Spec is not valid - storage size should be at least 1MiB"))
+	})
+
 	It("Should return the same volume size (block volume mode)", func() {
 		volumeMode := corev1.PersistentVolumeBlock
 		pvcSpec := &corev1.PersistentVolumeClaimSpec{
 			StorageClassName: &scName,
 			VolumeMode:       &volumeMode,
-			Resources: corev1.ResourceRequirements{
+			Resources: corev1.VolumeResourceRequirements{
 				Requests: corev1.ResourceList{
 					corev1.ResourceStorage: volumeSize,
 				},
@@ -70,7 +87,7 @@ var _ = Describe("renderPvcSpecVolumeSize", func() {
 		pvcSpec := &corev1.PersistentVolumeClaimSpec{
 			StorageClassName: &scName,
 			VolumeMode:       &volumeMode,
-			Resources: corev1.ResourceRequirements{
+			Resources: corev1.VolumeResourceRequirements{
 				Requests: corev1.ResourceList{
 					corev1.ResourceStorage: volumeSize,
 				},
@@ -99,12 +116,16 @@ var _ = Describe("updateDataVolumeDefaultInstancetypeLabels", func() {
 	const (
 		namespace            = "namespace"
 		sourcePVCName        = "sourcePVC"
+		sourceSnapshotName   = "sourceSnapshot"
+		sourceRegistryName   = "sourceRegistry"
 		sourceDataSourceName = "sourceDataSource"
 	)
 
 	var (
 		fakeClient                     client.Client
 		dataVolumeWithSourcePVC        cdiv1.DataVolume
+		dataVolumeWithSourceSnapshot   cdiv1.DataVolume
+		dataVolumeWithSourceRegistry   cdiv1.DataVolume
 		dataVolumeWithSourceDataSource cdiv1.DataVolume
 	)
 
@@ -131,6 +152,35 @@ var _ = Describe("updateDataVolumeDefaultInstancetypeLabels", func() {
 			},
 		}
 
+		dataVolumeWithSourceSnapshot = cdiv1.DataVolume{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:      "snapshot-datavolume",
+				Namespace: namespace,
+			},
+			Spec: cdiv1.DataVolumeSpec{
+				Source: &cdiv1.DataVolumeSource{
+					Snapshot: &cdiv1.DataVolumeSourceSnapshot{
+						Name:      sourceSnapshotName,
+						Namespace: namespace,
+					},
+				},
+			},
+		}
+
+		dataVolumeWithSourceRegistry = cdiv1.DataVolume{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:      sourceRegistryName,
+				Namespace: namespace,
+			},
+			Spec: cdiv1.DataVolumeSpec{
+				Source: &cdiv1.DataVolumeSource{
+					Registry: &cdiv1.DataVolumeSourceRegistry{
+						URL: ptr.To("docker://testurl"),
+					},
+				},
+			},
+		}
+
 		dataVolumeWithSourceDataSource = cdiv1.DataVolume{
 			ObjectMeta: metav1.ObjectMeta{
 				Name:      "datasource-datavolume",
@@ -152,6 +202,20 @@ var _ = Describe("updateDataVolumeDefaultInstancetypeLabels", func() {
 					Labels:    defaultInstancetypeLabelMap,
 				},
 			},
+			&snapshotv1.VolumeSnapshot{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      sourceSnapshotName,
+					Namespace: namespace,
+					Labels:    defaultInstancetypeLabelMap,
+				},
+			},
+			&corev1.PersistentVolumeClaim{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      sourceRegistryName,
+					Namespace: namespace,
+					Labels:    defaultInstancetypeLabelMap,
+				},
+			},
 			&cdiv1.DataSource{
 				ObjectMeta: metav1.ObjectMeta{
 					Name:      sourceDataSourceName,
@@ -181,6 +245,8 @@ var _ = Describe("updateDataVolumeDefaultInstancetypeLabels", func() {
 		}
 	},
 		Entry("PVC", &dataVolumeWithSourcePVC),
+		Entry("Snapshot", &dataVolumeWithSourceSnapshot),
+		Entry("Registry", &dataVolumeWithSourceRegistry),
 		Entry("dataSource", &dataVolumeWithSourceDataSource),
 	)
 
@@ -199,6 +265,8 @@ var _ = Describe("updateDataVolumeDefaultInstancetypeLabels", func() {
 		Expect(syncState.dvMutated.Labels).To(HaveKeyWithValue(LabelDefaultInstancetype, customDefaultInstancetype))
 	},
 		Entry("PVC", &dataVolumeWithSourcePVC),
+		Entry("Snapshot", &dataVolumeWithSourceSnapshot),
+		Entry("Registry", &dataVolumeWithSourceRegistry),
 		Entry("DataSource", &dataVolumeWithSourceDataSource),
 	)
 
@@ -222,6 +290,33 @@ var _ = Describe("updateDataVolumeDefaultInstancetypeLabels", func() {
 				},
 			},
 		}),
+		Entry("Snapshot", &cdiv1.DataVolume{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:      "snapshot-datavolume",
+				Namespace: namespace,
+			},
+			Spec: cdiv1.DataVolumeSpec{
+				Source: &cdiv1.DataVolumeSource{
+					Snapshot: &cdiv1.DataVolumeSourceSnapshot{
+						Name:      "unknown",
+						Namespace: namespace,
+					},
+				},
+			},
+		}),
+		Entry("Registry", &cdiv1.DataVolume{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:      "registry-datavolume-unknown",
+				Namespace: namespace,
+			},
+			Spec: cdiv1.DataVolumeSpec{
+				Source: &cdiv1.DataVolumeSource{
+					Registry: &cdiv1.DataVolumeSourceRegistry{
+						URL: ptr.To("docker://uknown"),
+					},
+				},
+			},
+		}),
 		Entry("DataSource", &cdiv1.DataVolume{
 			ObjectMeta: metav1.ObjectMeta{
 				Name:      "datasource-datavolume",
@@ -249,6 +344,8 @@ var _ = Describe("updateDataVolumeDefaultInstancetypeLabels", func() {
 		Expect(errors.IsServiceUnavailable(err)).To(BeTrue())
 	},
 		Entry("PVC", &dataVolumeWithSourcePVC),
+		Entry("Snapshot", &dataVolumeWithSourceSnapshot),
+		Entry("Registry", &dataVolumeWithSourceRegistry),
 		Entry("DataSource", &dataVolumeWithSourceDataSource),
 	)
 })
@@ -272,6 +369,7 @@ func createClient(objs ...client.Object) client.Client {
 	_ = cdiv1.AddToScheme(s)
 	// Register other types with the runtime scheme.
 	_ = ocpconfigv1.Install(s)
+	_ = snapshotv1.AddToScheme(s)
 	// Create a fake client to mock API calls.
 	return fake.NewClientBuilder().WithScheme(s).WithObjects(objs...).Build()
 }
