@@ -318,9 +318,9 @@ func setAnnotationsFromPodWithPrefix(anno map[string]string, pod *corev1.Pod, te
 	anno[cc.AnnRunningCondition] = "false"
 
 	for _, status := range pod.Status.ContainerStatuses {
-		if status.Started != nil && !(*status.Started) {
-			if status.State.Waiting != nil &&
-				(status.State.Waiting.Reason == "ImagePullBackOff" || status.State.Waiting.Reason == "ErrImagePull") {
+		if status.Started != nil && !(*status.Started) && status.State.Waiting != nil {
+			switch status.State.Waiting.Reason {
+			case "ImagePullBackOff", "ErrImagePull", "InvalidImageName":
 				anno[prefix+".message"] = fmt.Sprintf("%s: %s", common.ImagePullFailureText, status.Image)
 				anno[prefix+".reason"] = ImagePullFailedReason
 				return
