@@ -103,12 +103,12 @@ var _ = Describe("Http data source", func() {
 		Entry("return TransferTarget with archive content type and archive endpoint ", diskimageTarFileName, cdiv1.DataVolumeArchive, ProcessingPhaseTransferDataDir, diskimageArchiveData, false),
 	)
 
-	It("calling info with raw gz image should return TransferDataFile", func() {
+	It("calling info with raw gz image should return TransferScratch", func() {
 		dp, err = NewHTTPDataSource(ts.URL+"/"+tinyCoreGz, "", "", "", cdiv1.DataVolumeKubeVirt)
 		Expect(err).NotTo(HaveOccurred())
 		newPhase, err := dp.Info()
 		Expect(err).NotTo(HaveOccurred())
-		Expect(ProcessingPhaseTransferDataFile).To(Equal(newPhase))
+		Expect(ProcessingPhaseTransferScratch).To(Equal(newPhase))
 	})
 
 	DescribeTable("calling transfer should", func(image string, contentType cdiv1.DataVolumeContentType, expectedPhase ProcessingPhase, scratchPath string, want []byte, wantErr bool) {
@@ -149,20 +149,20 @@ var _ = Describe("Http data source", func() {
 		Entry("return Convert with scratch space and valid qcow file", cirrosFileName, cdiv1.DataVolumeKubeVirt, ProcessingPhaseConvert, "", cirrosData, false),
 	)
 
-	It("TransferFile should succeed when writing to valid file, and reading raw gz", func() {
+	It("TransferScratch should succeed when writing to valid file, and reading raw gz", func() {
 		dp, err = NewHTTPDataSource(ts.URL+"/"+tinyCoreGz, "", "", "", cdiv1.DataVolumeKubeVirt)
 		Expect(err).NotTo(HaveOccurred())
 		result, err := dp.Info()
 		Expect(err).NotTo(HaveOccurred())
-		Expect(ProcessingPhaseTransferDataFile).To(Equal(result))
+		Expect(ProcessingPhaseTransferScratch).To(Equal(result))
 	})
 
-	It("TransferFile should succeed when writing to valid file and reading raw xz", func() {
+	It("TransferScratch should succeed when writing to valid file and reading raw xz", func() {
 		dp, err = NewHTTPDataSource(ts.URL+"/"+tinyCoreXz, "", "", "", cdiv1.DataVolumeKubeVirt)
 		Expect(err).NotTo(HaveOccurred())
 		result, err := dp.Info()
 		Expect(err).NotTo(HaveOccurred())
-		Expect(ProcessingPhaseTransferDataFile).To(Equal(result))
+		Expect(ProcessingPhaseTransferScratch).To(Equal(result))
 	})
 
 	It("should get extra headers on creation of new HTTP data source", func() {
@@ -179,7 +179,7 @@ var _ = Describe("Http data source", func() {
 				Expect(err).NotTo(HaveOccurred())
 				_, _ = w.Write(body)
 			} else {
-				w.WriteHeader(500)
+				w.WriteHeader(http.StatusInternalServerError)
 			}
 		}))
 		dp, err = NewHTTPDataSource(ts2.URL+"/"+tinyCoreGz, "", "", "", cdiv1.DataVolumeKubeVirt)
@@ -256,7 +256,7 @@ var _ = Describe("Http client", func() {
 
 		certBytes := cert.EncodeCertPEM(keyPair.Cert)
 
-		err = os.WriteFile(path.Join(tempDir, "tls.crt"), certBytes, 0644)
+		err = os.WriteFile(path.Join(tempDir, "tls.crt"), certBytes, 0600)
 		Expect(err).ToNot(HaveOccurred())
 	})
 
@@ -294,7 +294,7 @@ var _ = Describe("Http reader", func() {
 	It("should pass auth info in request if set", func() {
 		ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 			user, pass, ok := r.BasicAuth()
-			defer w.WriteHeader(200)
+			defer w.WriteHeader(http.StatusOK)
 			Expect(ok).To(BeTrue())
 			Expect("user").To(Equal(user))
 			Expect("password").To(Equal(pass))
@@ -378,7 +378,7 @@ var _ = Describe("Http reader", func() {
 
 	It("should continue even if HEAD is rejected, but mark broken for qemu-img", func() {
 		redirTs := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
-			if r.Method == "HEAD" {
+			if r.Method == http.MethodHead {
 				w.WriteHeader(http.StatusForbidden)
 			} else {
 				defer w.WriteHeader(http.StatusOK)
@@ -423,7 +423,7 @@ var _ = Describe("Http reader", func() {
 
 	It("should fail if server returns error code", func() {
 		ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
-			w.WriteHeader(500)
+			w.WriteHeader(http.StatusInternalServerError)
 		}))
 		defer ts.Close()
 		ep, err := url.Parse(ts.URL)
@@ -437,9 +437,9 @@ var _ = Describe("Http reader", func() {
 	It("should pass through extra headers", func() {
 		ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 			if _, exists := r.Header["Extra-Header"]; exists {
-				w.WriteHeader(200)
+				w.WriteHeader(http.StatusOK)
 			} else {
-				w.WriteHeader(500)
+				w.WriteHeader(http.StatusInternalServerError)
 			}
 		}))
 		defer ts.Close()
