@@ -224,7 +224,7 @@ var _ = Describe("VDDK data source", func() {
 
 		phase, err = snap2.TransferFile(".")
 		Expect(err).ToNot(HaveOccurred())
-		Expect(phase).To(Equal(ProcessingPhaseResize))
+		Expect(phase).To(Equal(ProcessingPhaseComplete))
 
 		deltaSum := md5.Sum(mockSinkBuffer) //nolint:gosec // This is test code
 		Expect(changedSourceSum).To(Equal(deltaSum))
@@ -254,8 +254,9 @@ var _ = Describe("VDDK data source", func() {
 			return nil
 		}
 
+		counter := 0
 		changeInfo := types.DiskChangeInfo{
-			StartOffset: 100,
+			StartOffset: 0,
 			Length:      1000,
 			ChangedArea: []types.DiskChangeExtent{
 				{
@@ -265,6 +266,12 @@ var _ = Describe("VDDK data source", func() {
 			},
 		}
 		QueryChangedDiskAreas = func(ctx context.Context, r soap.RoundTripper, req *types.QueryChangedDiskAreas) (*types.QueryChangedDiskAreasResponse, error) {
+			if counter > 0 {
+				return &types.QueryChangedDiskAreasResponse{
+					Returnval: types.DiskChangeInfo{},
+				}, nil
+			}
+			counter++
 			return &types.QueryChangedDiskAreasResponse{
 				Returnval: changeInfo,
 			}, nil
@@ -279,9 +286,9 @@ var _ = Describe("VDDK data source", func() {
 		var returnedDiskName string
 
 		newVddkDataSource = createVddkDataSource
-		newNbdKitWrapper = func(vmware *VMwareClient, fileName string) (*NbdKitWrapper, error) {
+		newNbdKitWrapper = func(vmware *VMwareClient, fileName, snapshot string) (*NbdKitWrapper, error) {
 			returnedDiskName = fileName
-			return createMockNbdKitWrapper(vmware, fileName)
+			return createMockNbdKitWrapper(vmware, fileName, snapshot)
 		}
 		currentVMwareFunctions.Properties = func(ctx context.Context, ref types.ManagedObjectReference, property []string, result interface{}) error {
 			switch out := result.(type) {
@@ -315,6 +322,38 @@ var _ = Describe("VDDK data source", func() {
 		Entry("should fail if backing file is not found in snapshot tree", "[teststore] testvm/testfile.vmdk", "wrong disk 1.vmdk", "wrong disk 2.vmdk", "wrong disk 1.vmdk", false),
 	)
 
+	It("should pass snapshot reference through to nbdkit", func() {
+		expectedSnapshot := "snapshot-10"
+
+		var receivedSnapshotRef string
+		newVddkDataSource = createVddkDataSource
+		newNbdKitWrapper = func(vmware *VMwareClient, fileName, snapshot string) (*NbdKitWrapper, error) {
+			receivedSnapshotRef = snapshot
+			return createMockNbdKitWrapper(vmware, fileName, snapshot)
+		}
+
+		currentVMwareFunctions.Properties = func(ctx context.Context, ref types.ManagedObjectReference, property []string, result interface{}) error {
+			switch out := result.(type) {
+			case *mo.VirtualMachine:
+				if property[0] == "config.hardware.device" {
+					out.Config = createVirtualDiskConfig("disk1", 12345)
+				} else if property[0] == "snapshot" {
+					out.Snapshot = createSnapshots(expectedSnapshot, "snapshot-11")
+				}
+			case *mo.VirtualMachineSnapshot:
+				out.Config = *createVirtualDiskConfig("snapshot-disk", 123456)
+				disk := out.Config.Hardware.Device[0].(*types.VirtualDisk)
+				parent := disk.Backing.(*types.VirtualDiskFlatVer1BackingInfo).Parent
+				parent.FileName = "snapshot-root"
+			}
+			return nil
+		}
+
+		_, err := NewVDDKDataSource("http://vcenter.test", "user", "pass", "aa:bb:cc:dd", "1-2-3-4", "disk1", expectedSnapshot, "", "", v1.PersistentVolumeFilesystem)
+		Expect(err).ToNot(HaveOccurred())
+		Expect(receivedSnapshotRef).To(Equal(expectedSnapshot))
+	})
+
 	It("should find two snapshots and get a list of changed blocks", func() {
 		newVddkDataSource = createVddkDataSource
 		diskName := "testdisk.vmdk"
@@ -347,7 +386,6 @@ var _ = Describe("VDDK data source", func() {
 			}
 			return nil, errors.New("could not find snapshot")
 		}
-
 		changedBlockList := types.DiskChangeInfo{
 			StartOffset: 0,
 			Length:      10240,
@@ -362,10 +400,21 @@ var _ = Describe("VDDK data source", func() {
 				},
 			},
 		}
+		counter := 0
 		currentVMwareFunctions.QueryChangedDiskAreas = func(ctx context.Context, baseSnapshot *types.ManagedObjectReference, changedSnapshot *types.ManagedObjectReference, disk *types.VirtualDisk, offset int64) (types.DiskChangeInfo, error) {
-			return changedBlockList, nil
+			var resp types.DiskChangeInfo
+			if counter == 0 {
+				resp = changedBlockList
+			} else {
+				resp = types.DiskChangeInfo{
+					StartOffset: 10240,
+					Length:      0,
+					ChangedArea: []types.DiskChangeExtent{},
+				}
+			}
+			counter++
+			return resp, nil
 		}
-
 		// Expect source.ChangedBlocks to equal local changed blocks
 		source, err := NewVDDKDataSource("http://vcenter.test", "user", "pass", "aa:bb:cc:dd", "1-2-3-4", diskName, "snapshot-1", "snapshot-2", "false", v1.PersistentVolumeFilesystem)
 		Expect(err).ToNot(HaveOccurred())
@@ -448,6 +497,95 @@ var _ = Describe("VDDK data source", func() {
 		vddkHost = testHost
 		Expect(*source.GetTerminationMessage()).To(Equal(common.TerminationMessage{VddkInfo: &common.VddkInfo{Version: testVersion, Host: testHost}}))
 	})
+	It("VDDK return more than 2000 changed block area", func() {
+		diskName := "disk"
+		snapshotName := "checkpoint-2"
+		changeID := "52 de c0 d9 b9 43 9d 10-61 d5 4c 1b e9 7b 65 63/81"
+		newVddkDataSource = createVddkDataSource
+
+		snapshots := createSnapshots(snapshotName, "")
+		currentVMwareFunctions.FindSnapshot = func(ctx context.Context, nameOrID string) (*types.ManagedObjectReference, error) {
+			return &snapshots.RootSnapshotList[0].Snapshot, nil
+		}
+		currentVMwareFunctions.Properties = func(ctx context.Context, ref types.ManagedObjectReference, property []string, result interface{}) error {
+			switch out := result.(type) {
+			case *mo.VirtualMachine:
+				if property[0] == "config.hardware.device" {
+					out.Config = createVirtualDiskConfigWithSize(diskName, 12345, 9563078656)
+				} else if property[0] == "snapshot" {
+					out.Snapshot = snapshots
+				}
+			case *mo.VirtualMachineSnapshot:
+				out.Config = *createVirtualDiskConfigWithSize("snapshotdisk", 123456, 9563078656)
+			}
+			return nil
+		}
+
+		expectedInfo := types.DiskChangeInfo{
+			StartOffset: 0,
+			Length:      9563078656,
+			ChangedArea: []types.DiskChangeExtent{},
+		}
+		for i := 0; i < 4500; i++ {
+			expectedInfo.ChangedArea = append(expectedInfo.ChangedArea, types.DiskChangeExtent{})
+		}
+		counter := 0
+		QueryChangedDiskAreas = func(ctx context.Context, r soap.RoundTripper, req *types.QueryChangedDiskAreas) (*types.QueryChangedDiskAreasResponse, error) {
+			var resp *types.QueryChangedDiskAreasResponse
+			if counter == 0 {
+				respInfo := types.DiskChangeInfo{
+					StartOffset: 0,
+					Length:      4194369536,
+					ChangedArea: []types.DiskChangeExtent{},
+				}
+				for i := 0; i < 2000; i++ {
+					respInfo.ChangedArea = append(respInfo.ChangedArea, types.DiskChangeExtent{})
+				}
+				resp = &types.QueryChangedDiskAreasResponse{
+					Returnval: respInfo,
+				}
+			} else if counter == 1 {
+				respInfo := types.DiskChangeInfo{
+					StartOffset: 4194369536,
+					Length:      4194369536,
+					ChangedArea: []types.DiskChangeExtent{},
+				}
+				for i := 0; i < 2000; i++ {
+					respInfo.ChangedArea = append(respInfo.ChangedArea, types.DiskChangeExtent{})
+				}
+				resp = &types.QueryChangedDiskAreasResponse{
+					Returnval: respInfo,
+				}
+			} else if counter == 2 {
+				respInfo := types.DiskChangeInfo{
+					StartOffset: 8388739072,
+					Length:      1174339584,
+					ChangedArea: []types.DiskChangeExtent{},
+				}
+				for i := 0; i < 500; i++ {
+					respInfo.ChangedArea = append(respInfo.ChangedArea, types.DiskChangeExtent{})
+				}
+				resp = &types.QueryChangedDiskAreasResponse{
+					Returnval: respInfo,
+				}
+			} else {
+				respInfo := types.DiskChangeInfo{
+					StartOffset: 9563078656,
+					Length:      0,
+					ChangedArea: []types.DiskChangeExtent{},
+				}
+				resp = &types.QueryChangedDiskAreasResponse{
+					Returnval: respInfo,
+				}
+			}
+			counter++
+			return resp, nil
+		}
+
+		ds, err := NewVDDKDataSource("http://vcenter.test", "user", "pass", "aa:bb:cc:dd", "1-2-3-4", diskName, snapshotName, changeID, "", v1.PersistentVolumeFilesystem)
+		Expect(err).ToNot(HaveOccurred())
+		Expect(ds.ChangedBlocks).To(Equal(&expectedInfo))
+	})
 })
 
 var _ = Describe("VDDK log watcher", func() {
@@ -880,7 +1018,7 @@ func createMockVMwareClient(endpoint string, accessKey string, secKey string, th
 	}, nil
 }
 
-func createMockNbdKitWrapper(vmware *VMwareClient, diskFileName string) (*NbdKitWrapper, error) {
+func createMockNbdKitWrapper(vmware *VMwareClient, diskFileName, snapshot string) (*NbdKitWrapper, error) {
 	u, _ := url.Parse("http://vcenter.test")
 	return &NbdKitWrapper{
 		n:      &image.Nbdkit{},
@@ -909,6 +1047,27 @@ func createVirtualDiskConfig(fileName string, key int32) *types.VirtualMachineCo
 		},
 	}
 }
+func createVirtualDiskConfigWithSize(fileName string, key int32, size int64) *types.VirtualMachineConfigInfo {
+	return &types.VirtualMachineConfigInfo{
+		Hardware: types.VirtualHardware{
+			Device: []types.BaseVirtualDevice{
+				&types.VirtualDisk{
+					DiskObjectId:    "test-1",
+					CapacityInBytes: size,
+					VirtualDevice: types.VirtualDevice{
+						Key: key,
+						Backing: &types.VirtualDiskFlatVer1BackingInfo{
+							VirtualDeviceFileBackingInfo: types.VirtualDeviceFileBackingInfo{
+								FileName: fileName,
+							},
+							Parent: &types.VirtualDiskFlatVer1BackingInfo{},
+						},
+					},
+				},
+			},
+		},
+	}
+}
 
 func createSnapshots(name1 string, name2 string) *types.VirtualMachineSnapshotInfo {
 	return &types.VirtualMachineSnapshotInfo{
