@@ -2,6 +2,7 @@ package cdicontroller
 
 import (
 	"github.com/machadovilaca/operator-observability/pkg/operatormetrics"
+
 	runtimemetrics "sigs.k8s.io/controller-runtime/pkg/metrics"
 )
 
@@ -14,8 +15,3 @@ func SetupMetrics() error {
 		dataVolumeMetrics,
 	)
 }
-
-// ListMetrics registered prometheus metrics
-func ListMetrics() []operatormetrics.Metric {
-	return operatormetrics.ListMetrics()
-}
