@@ -35,6 +35,7 @@ import (
 	"k8s.io/client-go/kubernetes"
 	listerscorev1 "k8s.io/client-go/listers/core/v1"
 	toolscache "k8s.io/client-go/tools/cache"
+	"k8s.io/utils/clock"
 
 	"sigs.k8s.io/controller-runtime/pkg/manager"
 
@@ -76,7 +77,7 @@ func NewCertManager(mgr manager.Manager, installNamespace string, additionalName
 		return nil, err
 	}
 
-	cm := newCertManager(k8sClient, installNamespace, additionalNamespaces...)
+	cm := newCertManager(k8sClient, installNamespace, clock.RealClock{}, additionalNamespaces...)
 
 	// so we can start caches
 	if err = mgr.Add(cm); err != nil {
@@ -86,7 +87,7 @@ func NewCertManager(mgr manager.Manager, installNamespace string, additionalName
 	return cm, nil
 }
 
-func newCertManager(client kubernetes.Interface, installNamespace string, additionalNamespaces ...string) *certManager {
+func newCertManager(client kubernetes.Interface, installNamespace string, clock clock.PassiveClock, additionalNamespaces ...string) *certManager {
 	namespaces := append(additionalNamespaces, installNamespace)
 	informers := v1helpers.NewKubeInformersForNamespaces(client, namespaces...)
 
@@ -95,7 +96,7 @@ func newCertManager(client kubernetes.Interface, installNamespace string, additi
 		log.Info("Unable to get controller reference, using namespace")
 	}
 
-	eventRecorder := events.NewRecorder(client.CoreV1().Events(installNamespace), installNamespace, controllerRef)
+	eventRecorder := events.NewRecorder(client.CoreV1().Events(installNamespace), installNamespace, controllerRef, clock)
 
 	return &certManager{
 		namespaces:    namespaces,
@@ -196,27 +197,15 @@ func (cm *certManager) ensureCertConfig(secret *corev1.Secret, certConfig cdicer
 	return secret, nil
 }
 
-func (cm *certManager) createOrGetSecret(namespace, name string) (*corev1.Secret, error) {
+func (cm *certManager) createSecret(namespace, name string) (*corev1.Secret, error) {
 	secret := &corev1.Secret{
 		ObjectMeta: metav1.ObjectMeta{
 			Name: name,
 		},
+		Type: corev1.SecretTypeTLS,
 	}
 
-	secret, err := cm.k8sClient.CoreV1().Secrets(namespace).Create(context.TODO(), secret, metav1.CreateOptions{})
-	if err != nil {
-		if !errors.IsAlreadyExists(err) {
-			return nil, err
-		}
-
-		// skip the cache
-		secret, err = cm.k8sClient.CoreV1().Secrets(namespace).Get(context.TODO(), name, metav1.GetOptions{})
-		if err != nil {
-			return nil, err
-		}
-	}
-
-	return secret, nil
+	return cm.k8sClient.CoreV1().Secrets(namespace).Create(context.TODO(), secret, metav1.CreateOptions{})
 }
 
 func (cm *certManager) ensureSigner(cd cdicerts.CertificateDefinition) (*crypto.CA, error) {
@@ -231,7 +220,7 @@ func (cm *certManager) ensureSigner(cd cdicerts.CertificateDefinition) (*crypto.
 			return nil, err
 		}
 
-		secret, err = cm.createOrGetSecret(cd.SignerSecret.Namespace, cd.SignerSecret.Name)
+		secret, err = cm.createSecret(cd.SignerSecret.Namespace, cd.SignerSecret.Name)
 		if err != nil {
 			return nil, err
 		}
@@ -274,7 +263,7 @@ func (cm *certManager) ensureCertBundle(cd cdicerts.CertificateDefinition, ca *c
 		EventRecorder: cm.eventRecorder,
 	}
 
-	certs, err := br.EnsureConfigMapCABundle(context.TODO(), ca)
+	certs, err := br.EnsureConfigMapCABundle(context.TODO(), ca, fmt.Sprintf("%s/%s", cd.SignerSecret.Namespace, cd.SignerSecret.Name))
 	if err != nil {
 		return nil, err
 	}
@@ -294,7 +283,7 @@ func (cm *certManager) ensureTarget(cd cdicerts.CertificateDefinition, ca *crypt
 			return err
 		}
 
-		secret, err = cm.createOrGetSecret(cd.TargetSecret.Namespace, cd.TargetSecret.Name)
+		secret, err = cm.createSecret(cd.TargetSecret.Namespace, cd.TargetSecret.Name)
 		if err != nil {
 			return err
 		}
