@@ -13,8 +13,11 @@ import (
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/client-go/kubernetes"
 	"k8s.io/client-go/kubernetes/fake"
+	"k8s.io/client-go/testing"
+	clocktesting "k8s.io/utils/clock/testing"
 
 	"sigs.k8s.io/controller-runtime/pkg/client"
 
@@ -23,6 +26,31 @@ import (
 
 const testCertData = "test"
 
+var secretNames = []string{
+	"cdi-apiserver-signer", "cdi-apiserver-server-cert",
+	"cdi-uploadproxy-signer", "cdi-uploadproxy-server-cert",
+	"cdi-uploadserver-signer", "cdi-uploadserver-client-signer", "cdi-uploadserver-client-cert",
+}
+
+type noInformerStartCertManager struct {
+	*certManager
+}
+
+func (cm *noInformerStartCertManager) Start(ctx context.Context) error {
+	for _, ns := range cm.namespaces {
+		if cm.listerMap == nil {
+			cm.listerMap = make(map[string]*certListers)
+		}
+
+		cm.listerMap[ns] = &certListers{
+			secretLister:    cm.informers.InformersFor(ns).Core().V1().Secrets().Lister(),
+			configMapLister: cm.informers.InformersFor(ns).Core().V1().ConfigMaps().Lister(),
+		}
+	}
+
+	return nil
+}
+
 type fakeCertManager struct {
 	client    client.Client
 	namespace string
@@ -48,7 +76,10 @@ func newFakeCertManager(crClient client.Client, namespace string) CertManager {
 }
 
 func newCertManagerForTest(client kubernetes.Interface, namespace string) CertManager {
-	return newCertManager(client, namespace)
+	cm := newCertManager(client, namespace, clocktesting.NewFakePassiveClock(time.Now()))
+	return &noInformerStartCertManager{
+		certManager: cm,
+	}
 }
 
 func toSerializedCertConfig(l, r time.Duration) string {
@@ -72,7 +103,10 @@ func getCertConfigAnno(client kubernetes.Interface, namespace, name string) stri
 	s, err := client.CoreV1().Secrets(namespace).Get(context.TODO(), name, metav1.GetOptions{})
 	Expect(err).ToNot(HaveOccurred())
 	val, ok := s.Annotations["operator.cdi.kubevirt.io/certConfig"]
-	Expect(ok).To(BeTrue())
+	Expect(ok).To(BeTrue(), func() string {
+		secretJSON, _ := json.MarshalIndent(s, "", "    ")
+		return string(secretJSON)
+	})
 	return val
 }
 
@@ -86,16 +120,52 @@ func checkSecret(client kubernetes.Interface, namespace, name string, exists boo
 }
 
 func checkCerts(client kubernetes.Interface, namespace string, exists bool) {
-	checkSecret(client, namespace, "cdi-apiserver-signer", exists)
-	checkSecret(client, namespace, "cdi-apiserver-server-cert", exists)
+	for _, name := range secretNames {
+		checkSecret(client, namespace, name, exists)
+	}
+}
 
-	checkSecret(client, namespace, "cdi-uploadproxy-signer", exists)
-	checkSecret(client, namespace, "cdi-uploadproxy-server-cert", exists)
+func populateClientAndStoreWithSecrets(client kubernetes.Interface, cm *noInformerStartCertManager, ns string) {
+	for _, name := range secretNames {
+		secret := &corev1.Secret{
+			ObjectMeta: metav1.ObjectMeta{
+				Namespace: ns,
+				Name:      name,
+			},
+		}
+		Expect(
+			cm.informers.InformersFor(ns).Core().V1().Secrets().Informer().GetStore().Add(secret),
+		).To(Succeed())
+		_, err := client.CoreV1().Secrets(ns).Create(context.TODO(), secret, metav1.CreateOptions{})
+		Expect(err).ToNot(HaveOccurred())
+	}
+}
 
-	checkSecret(client, namespace, "cdi-uploadserver-signer", exists)
+func syncStoreWithClientCalls(client *fake.Clientset, cm *noInformerStartCertManager, ns string) {
+	// These reactors make sure that all client calls by the controller are
+	// reflected in its informers so Lister.Get() finds them
+	// Unit tests do not start the informers, this does not enqueue events!
+	client.Fake.PrependReactor("update", "secrets", func(action testing.Action) (handled bool, obj runtime.Object, err error) {
+		update, ok := action.(testing.UpdateAction)
+		Expect(ok).To(BeTrue())
+		secret, ok := update.GetObject().(*corev1.Secret)
+		Expect(ok).To(BeTrue())
+		Expect(
+			cm.informers.InformersFor(ns).Core().V1().Secrets().Informer().GetStore().Update(secret),
+		).To(Succeed())
+		return false, secret, nil
+	})
 
-	checkSecret(client, namespace, "cdi-uploadserver-client-signer", exists)
-	checkSecret(client, namespace, "cdi-uploadserver-client-cert", exists)
+	client.Fake.PrependReactor("create", "configmaps", func(action testing.Action) (handled bool, obj runtime.Object, err error) {
+		create, ok := action.(testing.CreateAction)
+		Expect(ok).To(BeTrue())
+		c, ok := create.GetObject().(*corev1.ConfigMap)
+		Expect(ok).To(BeTrue())
+		Expect(
+			cm.informers.InformersFor(ns).Core().V1().ConfigMaps().Informer().GetStore().Add(c),
+		).To(Succeed())
+		return false, c, nil
+	})
 }
 
 var _ = Describe("Cert rotation tests", func() {
@@ -111,10 +181,12 @@ var _ = Describe("Cert rotation tests", func() {
 			cm := newCertManagerForTest(client, namespace)
 
 			ctx, cancel := context.WithCancel(context.Background())
-			Expect(cm.(*certManager).Start(ctx)).To(Succeed())
+			Expect(cm.(*noInformerStartCertManager).Start(ctx)).To(Succeed())
 
 			checkCerts(client, namespace, false)
 
+			populateClientAndStoreWithSecrets(client, cm.(*noInformerStartCertManager), namespace)
+			syncStoreWithClientCalls(client, cm.(*noInformerStartCertManager), namespace)
 			certs := cert.CreateCertificateDefinitions(&cert.FactoryArgs{Namespace: namespace})
 			err := cm.Sync(certs)
 			Expect(err).ToNot(HaveOccurred())
@@ -136,9 +208,11 @@ var _ = Describe("Cert rotation tests", func() {
 
 			ctx, cancel := context.WithCancel(context.Background())
 			defer cancel()
-			Expect(cm.(*certManager).Start(ctx)).To(Succeed())
+			Expect(cm.(*noInformerStartCertManager).Start(ctx)).To(Succeed())
 
 			certs := cert.CreateCertificateDefinitions(&cert.FactoryArgs{Namespace: namespace})
+			populateClientAndStoreWithSecrets(client, cm.(*noInformerStartCertManager), namespace)
+			syncStoreWithClientCalls(client, cm.(*noInformerStartCertManager), namespace)
 			err := cm.Sync(certs)
 			Expect(err).ToNot(HaveOccurred())
 
