@@ -19,6 +19,8 @@ package namespaced
 import (
 	"fmt"
 
+	secv1 "github.com/openshift/api/security/v1"
+
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	rbacv1 "k8s.io/api/rbac/v1"
@@ -194,6 +196,11 @@ func createAPIServerDeployment(image, verbosity, pullPolicy string, imagePullSec
 			},
 		},
 	}
+	if deployment.Spec.Template.Annotations == nil {
+		deployment.Spec.Template.Annotations = make(map[string]string)
+	}
+	deployment.Spec.Template.Annotations[secv1.RequiredSCCAnnotation] = common.RestrictedSCCName
+
 	return deployment
 }
 
