@@ -26,11 +26,8 @@ import (
 	"k8s.io/apimachinery/pkg/labels"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/apimachinery/pkg/types"
-	"k8s.io/client-go/kubernetes/scheme"
 	"k8s.io/utils/ptr"
 
-	"sigs.k8s.io/controller-runtime/pkg/controller/controllerutil"
-
 	cdiv1 "kubevirt.io/containerized-data-importer-api/pkg/apis/core/v1beta1"
 	"kubevirt.io/containerized-data-importer/pkg/common"
 	controller "kubevirt.io/containerized-data-importer/pkg/controller/common"
@@ -60,7 +57,7 @@ var _ = Describe("[rfe_id:1115][crit:high][vendor:cnv-qe@redhat.com][level:compo
 		ns = f.Namespace.Name
 	})
 
-	DescribeTable("[test_id:2329] Should fail to import images that require too much space", func(uploadURL string) {
+	DescribeTable("[test_id:2329] Should fail to import images that require too much space", Label("no-kubernetes-in-docker"), func(uploadURL string) {
 		imageURL := fmt.Sprintf(uploadURL, f.CdiInstallNs)
 
 		By(imageURL)
@@ -160,7 +157,7 @@ var _ = Describe("[rfe_id:1115][crit:high][vendor:cnv-qe@redhat.com][level:compo
 		Expect(importer.DeletionTimestamp).To(BeNil())
 	})
 
-	It("[test_id:6688] Should retain all multi-stage importer pods after completion with dv annotation cdi.kubevirt.io/storage.pod.retainAfterCompletion=true", func() {
+	It("[test_id:6688] Should retain all multi-stage importer pods after completion with dv annotation cdi.kubevirt.io/storage.pod.retainAfterCompletion=true", Label("VDDK"), func() {
 		vcenterURL := fmt.Sprintf(utils.VcenterURL, f.CdiInstallNs)
 		dataVolume := f.CreateVddkWarmImportDataVolume("import-pod-retain-test", "100Mi", vcenterURL)
 
@@ -194,95 +191,6 @@ var _ = Describe("[rfe_id:1115][crit:high][vendor:cnv-qe@redhat.com][level:compo
 	})
 })
 
-var _ = Describe("DataVolume Garbage Collection", Serial, func() {
-	var (
-		f        = framework.NewFramework(namespacePrefix)
-		ns       string
-		err      error
-		config   *cdiv1.CDIConfig
-		origSpec *cdiv1.CDIConfigSpec
-	)
-
-	BeforeEach(func() {
-		ns = f.Namespace.Name
-		config, err = f.CdiClient.CdiV1beta1().CDIConfigs().Get(context.TODO(), common.ConfigName, metav1.GetOptions{})
-		Expect(err).ToNot(HaveOccurred())
-		origSpec = config.Spec.DeepCopy()
-	})
-
-	AfterEach(func() {
-		By("Restoring CDIConfig to original state")
-		err = utils.UpdateCDIConfig(f.CrClient, func(config *cdiv1.CDIConfigSpec) {
-			origSpec.DeepCopyInto(config)
-		})
-		Expect(err).ToNot(HaveOccurred())
-		Eventually(func() bool {
-			config, err = f.CdiClient.CdiV1beta1().CDIConfigs().Get(context.TODO(), common.ConfigName, metav1.GetOptions{})
-			Expect(err).ToNot(HaveOccurred())
-			return reflect.DeepEqual(config.Spec, *origSpec)
-		}, 30*time.Second, time.Second).Should(BeTrue())
-	})
-
-	verifyGC := func(dvName string) {
-		tests.VerifyGC(f, dvName, ns, true, config)
-	}
-
-	verifyNoGC := func(dvName string) {
-		tests.VerifyNoGC(f, dvName, ns)
-	}
-
-	verifyDisabledGC := func(dvName string) {
-		tests.VerifyDisabledGC(f, dvName, ns)
-	}
-
-	enableGcAndAnnotateLegacyDv := func(dvName string) {
-		tests.EnableGcAndAnnotateLegacyDv(f, dvName, ns)
-	}
-
-	DescribeTable("Should", func(ttl int, annDeleteAfterCompletion string, verifyGCFunc, additionalTestFunc func(dvName string), verifyContent bool) {
-		tests.SetConfigTTL(f, ttl)
-
-		dv := utils.NewDataVolumeWithHTTPImport("gc-test", "100Mi", fmt.Sprintf(utils.TinyCoreIsoURL, f.CdiInstallNs))
-		if annDeleteAfterCompletion != "" {
-			dv.Annotations[controller.AnnDeleteAfterCompletion] = annDeleteAfterCompletion
-		}
-		err = controllerutil.SetOwnerReference(config, dv, scheme.Scheme)
-		Expect(err).ToNot(HaveOccurred())
-
-		By(fmt.Sprintf("Create new datavolume %s", dv.Name))
-		dv, err := utils.CreateDataVolumeFromDefinition(f.CdiClient, ns, dv)
-		Expect(err).ToNot(HaveOccurred())
-
-		By("Verify pvc was created")
-		pvc, err := utils.WaitForPVC(f.K8sClient, ns, dv.Name)
-		Expect(err).ToNot(HaveOccurred())
-		f.ForceBindIfWaitForFirstConsumer(pvc)
-
-		verifyGCFunc(dv.Name)
-
-		if additionalTestFunc != nil {
-			additionalTestFunc(dv.Name)
-		}
-
-		if verifyContent {
-			By("Verify PVC content")
-			md5, err := f.GetMD5(f.Namespace, pvc, utils.DefaultImagePath, utils.MD5PrefixSize)
-			Expect(err).ToNot(HaveOccurred())
-			Expect(md5).To(Equal(utils.TinyCoreMD5))
-
-			By("Delete verifier pod")
-			err = utils.DeleteVerifierPod(f.K8sClient, f.Namespace.Name)
-			Expect(err).ToNot(HaveOccurred())
-		}
-	},
-		Entry("[test_id:8562] garbage collect dv after completion when TTL is 0", 0, "", verifyGC, nil, true),
-		Entry("[test_id:8563] not garbage collect dv after completion when TTL is disabled", -1, "", verifyDisabledGC, nil, false),
-		Entry("[test_id:8564] garbage collect dv after completion when TTL is 10s", 10, "", verifyGC, nil, true),
-		Entry("[test_id:8568] Add DeleteAfterCompletion annotation to a legacy DV", -1, "", verifyDisabledGC, enableGcAndAnnotateLegacyDv, true),
-		Entry("[test_id:8688] not garbage collect dv after completion when DeleteAfterCompletion is false", 0, "false", verifyNoGC, nil, false),
-	)
-})
-
 var _ = Describe("[Istio] Namespace sidecar injection", Serial, func() {
 	var (
 		f = framework.NewFramework(namespacePrefix)
@@ -928,7 +836,6 @@ var _ = Describe("[rfe_id:1115][crit:high][vendor:cnv-qe@redhat.com][level:compo
 		dvName := "import-dv"
 		By(fmt.Sprintf("Creating new datavolume %s", dvName))
 		dv := utils.NewDataVolumeWithHTTPImport(dvName, "100Mi", tinyCoreIsoURL())
-		dv.Annotations[controller.AnnDeleteAfterCompletion] = "false"
 		dataVolume, err = utils.CreateDataVolumeFromDefinition(f.CdiClient, f.Namespace.Name, dv)
 		Expect(err).ToNot(HaveOccurred())
 
@@ -1321,7 +1228,7 @@ var _ = Describe("Preallocation", func() {
 
 			return utils.NewDataVolumeWithHTTPImportToBlockPV("import-dv", "4Gi", tinyCoreQcow2URL(), f.BlockSCName)
 		}),
-		Entry("ImageIO import", Serial, true, utils.ImageioMD5, utils.DefaultImagePath, func() *cdiv1.DataVolume {
+		Entry("ImageIO import", Label("ImageIO"), Serial, true, utils.ImageioMD5, utils.DefaultImagePath, func() *cdiv1.DataVolume {
 			cm, err := utils.CopyImageIOCertConfigMap(f.K8sClient, f.Namespace.Name, f.CdiInstallNs)
 			Expect(err).ToNot(HaveOccurred())
 			stringData := map[string]string{
@@ -1361,7 +1268,7 @@ var _ = Describe("Preallocation", func() {
 			dataVolume.Annotations[controller.AnnPodRetainAfterCompletion] = "true"
 			return dataVolume
 		}),
-		Entry("VddkImport", true, utils.VcenterMD5, utils.DefaultImagePath, func() *cdiv1.DataVolume {
+		Entry("VddkImport", Label("VDDK"), true, utils.VcenterMD5, utils.DefaultImagePath, func() *cdiv1.DataVolume {
 			// Find vcenter-simulator pod
 			pod, err := utils.FindPodByPrefix(f.K8sClient, f.CdiInstallNs, "vcenter-deployment", "app=vcenter")
 			Expect(err).ToNot(HaveOccurred())
@@ -1700,10 +1607,10 @@ var _ = Describe("Import populator", func() {
 		Entry("[rfe_id:10985][crit:high][test_id:11003]with HTTP image and preallocation, with incomplete PVC webhook rendering", Serial, utils.TinyCoreMD5, createHTTPImportPopulatorCR, true, true),
 		Entry("[test_id:11004]with Registry image and preallocation", utils.TinyCoreMD5, createRegistryImportPopulatorCR, true, false),
 		Entry("[test_id:11005]with Registry image without preallocation", utils.TinyCoreMD5, createRegistryImportPopulatorCR, false, false),
-		Entry("[test_id:11006]with ImageIO image with preallocation", Serial, utils.ImageioMD5, createImageIOImportPopulatorCR, true, false),
-		Entry("[test_id:11007]with ImageIO image without preallocation", Serial, utils.ImageioMD5, createImageIOImportPopulatorCR, false, false),
-		Entry("[test_id:11008]with VDDK image with preallocation", utils.VcenterMD5, createVDDKImportPopulatorCR, true, false),
-		Entry("[test_id:11009]with VDDK image without preallocation", utils.VcenterMD5, createVDDKImportPopulatorCR, false, false),
+		Entry("[test_id:11006]with ImageIO image with preallocation", Label("ImageIO"), Serial, utils.ImageioMD5, createImageIOImportPopulatorCR, true, false),
+		Entry("[test_id:11007]with ImageIO image without preallocation", Label("ImageIO"), Serial, utils.ImageioMD5, createImageIOImportPopulatorCR, false, false),
+		Entry("[test_id:11008]with VDDK image with preallocation", Label("VDDK"), utils.VcenterMD5, createVDDKImportPopulatorCR, true, false),
+		Entry("[test_id:11009]with VDDK image without preallocation", Label("VDDK"), utils.VcenterMD5, createVDDKImportPopulatorCR, false, false),
 		Entry("[test_id:11010]with Blank image with preallocation", utils.BlankMD5, createBlankImportPopulatorCR, true, false),
 		Entry("[test_id:11011]with Blank image without preallocation", utils.BlankMD5, createBlankImportPopulatorCR, false, false),
 	)
@@ -1750,8 +1657,8 @@ var _ = Describe("Import populator", func() {
 	},
 		Entry("with HTTP image", utils.TinyCoreMD5, createHTTPImportPopulatorCR),
 		Entry("with Registry image", utils.TinyCoreMD5, createRegistryImportPopulatorCR),
-		Entry("with ImageIO image", Serial, utils.ImageioMD5, createImageIOImportPopulatorCR),
-		Entry("with VDDK image", utils.VcenterMD5, createVDDKImportPopulatorCR),
+		Entry("with ImageIO image", Label("ImageIO"), Serial, utils.ImageioMD5, createImageIOImportPopulatorCR),
+		Entry("with VDDK image", Label("VDDK"), utils.VcenterMD5, createVDDKImportPopulatorCR),
 		Entry("with Blank image", utils.BlankMD5, createBlankImportPopulatorCR),
 	)
 
@@ -1933,7 +1840,7 @@ var _ = Describe("Import populator", func() {
 		}, timeout, pollingInterval).Should(BeTrue())
 	})
 
-	It("Should do multi-stage import with dataVolume populator flow", func() {
+	It("Should do multi-stage import with dataVolume populator flow", Label("VDDK"), func() {
 		vcenterURL := fmt.Sprintf(utils.VcenterURL, f.CdiInstallNs)
 		dataVolume := f.CreateVddkWarmImportDataVolume("multi-stage-import-test", "100Mi", vcenterURL)
 		By(fmt.Sprintf("Create new datavolume %s", dataVolume.Name))
@@ -1950,7 +1857,7 @@ var _ = Describe("Import populator", func() {
 		Expect(err).ToNot(HaveOccurred(), "Datavolume not in phase succeeded in time")
 	})
 
-	It("Should update volumeImportSource accordingly when doing a multi-stage import", func() {
+	It("Should update volumeImportSource accordingly when doing a multi-stage import", Label("VDDK"), func() {
 		vcenterURL := fmt.Sprintf(utils.VcenterURL, f.CdiInstallNs)
 		dataVolume := f.CreateVddkWarmImportDataVolume("multi-stage-import-test", "100Mi", vcenterURL)
 
@@ -1989,7 +1896,7 @@ var _ = Describe("Import populator", func() {
 		}, timeout, pollingInterval).Should(BeTrue())
 	})
 
-	It("Should do multi-stage import with manually created volumeImportSource and PVC", func() {
+	It("Should do multi-stage import with manually created volumeImportSource and PVC", Label("VDDK"), func() {
 		pvcName := "multi-stage-import-pvc-test"
 		importSourceName := "multi-stage-import-test"
 		vcenterURL := fmt.Sprintf(utils.VcenterURL, f.CdiInstallNs)
