@@ -2,19 +2,18 @@ package utils
 
 import (
 	"context"
-
-	k8sv1 "k8s.io/api/core/v1"
-	"k8s.io/apimachinery/pkg/util/wait"
-	"k8s.io/client-go/kubernetes"
-
 	"fmt"
 	"time"
 
 	"github.com/onsi/ginkgo/v2"
+
+	k8sv1 "k8s.io/api/core/v1"
 	apierrs "k8s.io/apimachinery/pkg/api/errors"
 	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apimachinery/pkg/util/wait"
+	"k8s.io/client-go/kubernetes"
 )
 
 const (
@@ -45,7 +44,7 @@ func NewPVDefinition(pvName, size, storageClassName, node string, labels map[str
 			AccessModes:                   []k8sv1.PersistentVolumeAccessMode{k8sv1.ReadWriteOnce},
 			PersistentVolumeReclaimPolicy: k8sv1.PersistentVolumeReclaimDelete,
 			Capacity: k8sv1.ResourceList{
-				k8sv1.ResourceName(k8sv1.ResourceStorage): resource.MustParse(size),
+				k8sv1.ResourceStorage: resource.MustParse(size),
 			},
 			PersistentVolumeSource: k8sv1.PersistentVolumeSource{
 				Local: &k8sv1.LocalVolumeSource{
